#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from __future__ import print_function

from openeye import oechem
from openeye import oeshape


def main(argv=[__name__]):
    if len(argv) != 5:
        oechem.OEThrow.Usage("%s <reffile> <fitfile> <outfile> <nhits>" % argv[0])

    fitfs = oechem.oemolistream(sys.argv[2])
    outfs = oechem.oemolostream(sys.argv[3])
    nhits = int(sys.argv[4])

    query = oeshape.OEShapeQuery()
    oeshape.OEReadShapeQuery(sys.argv[1], query)

    # Setup OEROCS with specified number of best hits
    options = oeshape.OEROCSOptions()
    options.SetNumBestHits(nhits)
    rocs = oeshape.OEROCS(options)

    rocs.SetDatabase(fitfs)
    for res in rocs.Overlay(query):
        outmol = res.GetOverlayConf()
        oechem.OEWriteMolecule(outfs, outmol)
        print("title: %s  tanimoto combo = %.2f" % (outmol.GetTitle(), res.GetTanimotoCombo()))


if __name__ == "__main__":
    import sys
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict

# @ <SNIPPET-HIGHLIGHT-SIMPLE>
mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "c1cncc2c1cc3c(cncc3)c2")
oedepict.OEPrepareDepiction(mol)

subs = oechem.OESubSearch("c1ncccc1")
disp = oedepict.OE2DMolDisplay(mol)

unique = True
for match in subs.Match(mol, unique):
    oedepict.OEAddHighlighting(disp, oechem.OEColor(oechem.OERed), oedepict.OEHighlightStyle_Stick, match)

oedepict.OERenderMolecule("HighlightSimple.png", disp)
# @ </SNIPPET-HIGHLIGHT-SIMPLE>
oedepict.OERenderMolecule("HighlightSimple.pdf", disp)



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
from __future__ import print_function
from openeye import oechem


def CollectIncorrectStereo(mol):
    for atom in mol.GetAtoms():
        if atom.IsAromatic() and atom.HasStereoSpecified(oechem.OEAtomStereo_Tetrahedral):
            neighs = []
            for n in atom.GetAtoms():
                neighs.append(n.GetIdx())
            atom.SetData("incorrect_stereo_neighs", neighs)


def RemoveIncorrectStereo(mol):
    for atom in mol.GetAtoms():
        if atom.HasData("incorrect_stereo_neighs"):
            neighs = [mol.GetAtom(oechem.OEHasAtomIdx(a)) for a in atom.GetData("incorrect_stereo_neighs")]
            atom.SetStereo(neighs, oechem.OEAtomStereo_Tetrahedral, oechem.OEAtomStereo_Undefined)


mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "c1c[n@@H]cc1")
print(oechem.OEMolToSmiles(mol))

CollectIncorrectStereo(mol)
RemoveIncorrectStereo(mol)

print(oechem.OEMolToSmiles(mol))
# @ </SNIPPET>



# CONFIDENTIAL. (C) 2017 OpenEye Scientific Software Inc.
# All rights reserved.
# 
# ALL SOFTWARE BELOW IS PROPRIETARY AND CONFIDENTIAL TO OPENEYE
# SCIENTIFIC SOFTWARE INC., AND IS SUBJECT TO THE FULL PROTECTION OF
# COPYRIGHT AND TRADESECRET LAW.
# Copying or modifying this software is strictly prohibited and illegal.
# Using this software without a valid license from OpenEye is strictly
# prohibited and illegal.  De-obfuscating, de-minimizing, or any other
# attempt to reverse engineer or discover the workings of this software,
# is strictly prohibited. Even if software is exposed or visible, it is
# still proprietary and confidential and the above prohibitions apply.
# This software is NOT "Sample Code". For purposes of customization or
# interoperation with other software you must use Sample Code
# specifically labeled as such.
# Please contact OpenEye at eyesopen.com/legal if you have any questions
# about this warning.


# This file was automatically generated by SWIG (http://www.swig.org).
# Version 3.0.8
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.





from sys import version_info

def swig_import_helper():
    from os.path import dirname
    import imp
    fp = None
    try:
        fp, pathname, description = imp.find_module('_oechem', [dirname(__file__)])
    except ImportError:
        # OpenEye Import Statements
        fp, pathname, description = imp.find_module('libs', [dirname(__file__)])
        try:
            libs = imp.load_module('libs', fp, pathname, description)
        finally:
            if fp is not None:
                fp.close()

        import sys
        assert not sys.platform.startswith('win')
        
        _oespicoli = libs.OEGetModule('_oespicoli145')
        return _oespicoli

_oespicoli = swig_import_helper()
del swig_import_helper
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        object.__setattr__(self, name, value)
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0



def _swig_setattr_nondynamic_method(set):
    def set_attr(self, name, value):
        if (name == "thisown"):
            return self.this.own(value)
        if hasattr(self, name) or (name == "this"):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add attributes to %s" % self)
    return set_attr


try:
    import weakref
    weakref_proxy = weakref.proxy
except Exception:
    weakref_proxy = lambda x: x



def GetMainDict() -> "PyObject *":
    return _oespicoli.GetMainDict()
GetMainDict = _oespicoli.GetMainDict

def TypeToPyString(type: 'void const *') -> "PyObject *":
    return _oespicoli.TypeToPyString(type)
TypeToPyString = _oespicoli.TypeToPyString
class OEInternalFunctionPointer(object):
    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _oespicoli.new_OEInternalFunctionPointer(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def Add(self, b: 'OEBase', tag: 'unsigned int', data: 'PyObject *') -> "bool":
        return _oespicoli.OEInternalFunctionPointer_Add(self, b, tag, data)
    __swig_destroy__ = _oespicoli.delete_OEInternalFunctionPointer
    __del__ = lambda self: None
OEInternalFunctionPointer_swigregister = _oespicoli.OEInternalFunctionPointer_swigregister
OEInternalFunctionPointer_swigregister(OEInternalFunctionPointer)


def OEInternalGetGenericData(type: 'void const *') -> "OEInternalFunctionPointer *":
    return _oespicoli.OEInternalGetGenericData(type)
OEInternalGetGenericData = _oespicoli.OEInternalGetGenericData
import openeye.oechem as oechem

_oespicoli.OEVoxelizeMethod_Distance_swigconstant(_oespicoli)
OEVoxelizeMethod_Distance = _oespicoli.OEVoxelizeMethod_Distance

_oespicoli.OEVoxelizeMethod_Gaussian_swigconstant(_oespicoli)
OEVoxelizeMethod_Gaussian = _oespicoli.OEVoxelizeMethod_Gaussian

_oespicoli.OEVoxelizeMethod_Blank_swigconstant(_oespicoli)
OEVoxelizeMethod_Blank = _oespicoli.OEVoxelizeMethod_Blank

_oespicoli.OEVoxelizeMethod_Blur_swigconstant(_oespicoli)
OEVoxelizeMethod_Blur = _oespicoli.OEVoxelizeMethod_Blur

OEVoxelizeMethod_Default = OEVoxelizeMethod_Distance


_oespicoli.OEPolygonizeMethod_Grasp_swigconstant(_oespicoli)
OEPolygonizeMethod_Grasp = _oespicoli.OEPolygonizeMethod_Grasp

_oespicoli.OEPolygonizeMethod_Compact_swigconstant(_oespicoli)
OEPolygonizeMethod_Compact = _oespicoli.OEPolygonizeMethod_Compact

OEPolygonizeMethod_Default = OEPolygonizeMethod_Grasp


_oespicoli.OESurfaceFileType_UNDEFINED_swigconstant(_oespicoli)
OESurfaceFileType_UNDEFINED = _oespicoli.OESurfaceFileType_UNDEFINED

_oespicoli.OESurfaceFileType_Grasp_swigconstant(_oespicoli)
OESurfaceFileType_Grasp = _oespicoli.OESurfaceFileType_Grasp

_oespicoli.OESurfaceFileType_OESurface_swigconstant(_oespicoli)
OESurfaceFileType_OESurface = _oespicoli.OESurfaceFileType_OESurface

_oespicoli.OEEdgeReductionType_MinimumDistance_swigconstant(_oespicoli)
OEEdgeReductionType_MinimumDistance = _oespicoli.OEEdgeReductionType_MinimumDistance

_oespicoli.OERibbonType_CAlpha_swigconstant(_oespicoli)
OERibbonType_CAlpha = _oespicoli.OERibbonType_CAlpha

_oespicoli.OERibbonType_Pretty_swigconstant(_oespicoli)
OERibbonType_Pretty = _oespicoli.OERibbonType_Pretty

_oespicoli.OERibbonType_MAXTYPE_swigconstant(_oespicoli)
OERibbonType_MAXTYPE = _oespicoli.OERibbonType_MAXTYPE

def GetFloatFromPyObject(outfloat: 'float &', numberobj: 'PyObject *') -> "bool":
    """GetFloatFromPyObject(float & outfloat, PyObject * numberobj) -> bool"""
    return _oespicoli.GetFloatFromPyObject(outfloat, numberobj)

def GetIntFromPyObject(outint: 'unsigned int &', numberobj: 'PyObject *') -> "bool":
    """GetIntFromPyObject(unsigned int & outint, PyObject * numberobj) -> bool"""
    return _oespicoli.GetIntFromPyObject(outint, numberobj)
class OESurface(oechem.OEBase):
    """Proxy of C++ OESpicoli::OESurface class."""

    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __repr__ = _swig_repr

    def CreateCopy(self) -> "OESystem::OEBase *":
        """CreateCopy(OESurface self) -> OEBase"""
        return _oespicoli.OESurface_CreateCopy(self)


    def GetDataType(self) -> "void const *":
        """GetDataType(OESurface self) -> void const *"""
        return _oespicoli.OESurface_GetDataType(self)


    def IsDataType(self, type: 'void const *') -> "bool":
        """IsDataType(OESurface self, void const * type) -> bool"""
        return _oespicoli.OESurface_IsDataType(self, type)


    def __init__(self, *args):
        """
        __init__(OESpicoli::OESurface self) -> OESurface
        __init__(OESpicoli::OESurface self, OESurface rhs) -> OESurface
        __init__(OESpicoli::OESurface self, OESpicoli::OESurfaceImpl const & rhs) -> OESurface
        """
        this = _oespicoli.new_OESurface(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def IsValid(self):
      return _oespicoli.OESurface___nonzero__(self)


    __swig_destroy__ = _oespicoli.delete_OESurface
    __del__ = lambda self: None

    def Clear(self) -> "void":
        """Clear(OESurface self)"""
        return _oespicoli.OESurface_Clear(self)


    def SetTitle(self, title: 'char const *') -> "bool":
        """SetTitle(OESurface self, char const * title) -> bool"""
        return _oespicoli.OESurface_SetTitle(self, title)


    def GetTitle(self) -> "char const *":
        """GetTitle(OESurface self) -> char const *"""
        return _oespicoli.OESurface_GetTitle(self)


    def GetResolution(self) -> "float":
        """GetResolution(OESurface self) -> float"""
        return _oespicoli.OESurface_GetResolution(self)


    def GetProbeRadius(self) -> "float":
        """GetProbeRadius(OESurface self) -> float"""
        return _oespicoli.OESurface_GetProbeRadius(self)


    def GetNumVertices(self) -> "unsigned int":
        """GetNumVertices(OESurface self) -> unsigned int"""
        return _oespicoli.OESurface_GetNumVertices(self)


    def GetVertices(self, vertices: 'float *') -> "bool":
        """GetVertices(OESurface self, float * vertices) -> bool"""
        return _oespicoli.OESurface_GetVertices(self, vertices)


    def SetNumVertices(self, n: 'unsigned int') -> "bool":
        """SetNumVertices(OESurface self, unsigned int n) -> bool"""
        return _oespicoli.OESurface_SetNumVertices(self, n)


    def SetVertices(self, vertices: 'float const *') -> "bool":
        """SetVertices(OESurface self, float const * vertices) -> bool"""
        return _oespicoli.OESurface_SetVertices(self, vertices)


    def GetNumTriangles(self) -> "unsigned int":
        """GetNumTriangles(OESurface self) -> unsigned int"""
        return _oespicoli.OESurface_GetNumTriangles(self)


    def GetTriangles(self, triangles: 'unsigned int *') -> "bool":
        """GetTriangles(OESurface self, unsigned int * triangles) -> bool"""
        return _oespicoli.OESurface_GetTriangles(self, triangles)


    def SetNumTriangles(self, n: 'unsigned int') -> "bool":
        """SetNumTriangles(OESurface self, unsigned int n) -> bool"""
        return _oespicoli.OESurface_SetNumTriangles(self, n)


    def SetTriangles(self, triangles: 'unsigned int const *') -> "bool":
        """SetTriangles(OESurface self, unsigned int const * triangles) -> bool"""
        return _oespicoli.OESurface_SetTriangles(self, triangles)


    def IsNormalsSet(self) -> "bool":
        """IsNormalsSet(OESurface self) -> bool"""
        return _oespicoli.OESurface_IsNormalsSet(self)


    def GetNormals(self, normals: 'float *') -> "bool":
        """GetNormals(OESurface self, float * normals) -> bool"""
        return _oespicoli.OESurface_GetNormals(self, normals)


    def SetNormals(self, normals: 'float const *') -> "bool":
        """SetNormals(OESurface self, float const * normals) -> bool"""
        return _oespicoli.OESurface_SetNormals(self, normals)


    def IsFaceNormalsSet(self) -> "bool":
        """IsFaceNormalsSet(OESurface self) -> bool"""
        return _oespicoli.OESurface_IsFaceNormalsSet(self)


    def GetFaceNormals(self, faceNormals: 'float *') -> "bool":
        """GetFaceNormals(OESurface self, float * faceNormals) -> bool"""
        return _oespicoli.OESurface_GetFaceNormals(self, faceNormals)


    def SetFaceNormals(self, faceNormals: 'float const *') -> "bool":
        """SetFaceNormals(OESurface self, float const * faceNormals) -> bool"""
        return _oespicoli.OESurface_SetFaceNormals(self, faceNormals)


    def IsDistanceSet(self) -> "bool":
        """IsDistanceSet(OESurface self) -> bool"""
        return _oespicoli.OESurface_IsDistanceSet(self)


    def GetDistance(self, distance: 'float *') -> "bool":
        """GetDistance(OESurface self, float * distance) -> bool"""
        return _oespicoli.OESurface_GetDistance(self, distance)


    def GetDistanceElement(self, n: 'unsigned int') -> "float":
        """GetDistanceElement(OESurface self, unsigned int n) -> float"""
        return _oespicoli.OESurface_GetDistanceElement(self, n)


    def SetDistance(self, distance: 'float const *') -> "bool":
        """SetDistance(OESurface self, float const * distance) -> bool"""
        return _oespicoli.OESurface_SetDistance(self, distance)


    def SetDistanceElement(self, n: 'unsigned int', value: 'float') -> "bool":
        """SetDistanceElement(OESurface self, unsigned int n, float value) -> bool"""
        return _oespicoli.OESurface_SetDistanceElement(self, n, value)


    def IsPotentialSet(self) -> "bool":
        """IsPotentialSet(OESurface self) -> bool"""
        return _oespicoli.OESurface_IsPotentialSet(self)


    def GetPotential(self, potential: 'float *') -> "bool":
        """GetPotential(OESurface self, float * potential) -> bool"""
        return _oespicoli.OESurface_GetPotential(self, potential)


    def GetPotentialElement(self, n: 'unsigned int') -> "float":
        """GetPotentialElement(OESurface self, unsigned int n) -> float"""
        return _oespicoli.OESurface_GetPotentialElement(self, n)


    def SetPotential(self, potential: 'float const *') -> "bool":
        """SetPotential(OESurface self, float const * potential) -> bool"""
        return _oespicoli.OESurface_SetPotential(self, potential)


    def SetPotentialElement(self, n: 'unsigned int', value: 'float') -> "bool":
        """SetPotentialElement(OESurface self, unsigned int n, float value) -> bool"""
        return _oespicoli.OESurface_SetPotentialElement(self, n, value)


    def SetPotentialName(self, name: 'char const *') -> "void":
        """SetPotentialName(OESurface self, char const * name)"""
        return _oespicoli.OESurface_SetPotentialName(self, name)


    def GetPotentialName(self) -> "char const *":
        """GetPotentialName(OESurface self) -> char const *"""
        return _oespicoli.OESurface_GetPotentialName(self)


    def IsCurvatureSet(self) -> "bool":
        """IsCurvatureSet(OESurface self) -> bool"""
        return _oespicoli.OESurface_IsCurvatureSet(self)


    def GetCurvature(self, curvature: 'float *') -> "bool":
        """GetCurvature(OESurface self, float * curvature) -> bool"""
        return _oespicoli.OESurface_GetCurvature(self, curvature)


    def GetCurvatureElement(self, n: 'unsigned int') -> "float":
        """GetCurvatureElement(OESurface self, unsigned int n) -> float"""
        return _oespicoli.OESurface_GetCurvatureElement(self, n)


    def SetCurvature(self, curvature: 'float const *') -> "bool":
        """SetCurvature(OESurface self, float const * curvature) -> bool"""
        return _oespicoli.OESurface_SetCurvature(self, curvature)


    def SetCurvatureElement(self, n: 'unsigned int', value: 'float') -> "bool":
        """SetCurvatureElement(OESurface self, unsigned int n, float value) -> bool"""
        return _oespicoli.OESurface_SetCurvatureElement(self, n, value)


    def IsAtomsSet(self) -> "bool":
        """IsAtomsSet(OESurface self) -> bool"""
        return _oespicoli.OESurface_IsAtomsSet(self)


    def GetAtoms(self, atoms: 'unsigned int *') -> "bool":
        """GetAtoms(OESurface self, unsigned int * atoms) -> bool"""
        return _oespicoli.OESurface_GetAtoms(self, atoms)


    def GetAtomsElement(self, n: 'unsigned int') -> "unsigned int":
        """GetAtomsElement(OESurface self, unsigned int n) -> unsigned int"""
        return _oespicoli.OESurface_GetAtomsElement(self, n)


    def SetAtoms(self, atoms: 'unsigned int const *') -> "bool":
        """SetAtoms(OESurface self, unsigned int const * atoms) -> bool"""
        return _oespicoli.OESurface_SetAtoms(self, atoms)


    def SetAtomsElement(self, n: 'unsigned int', value: 'unsigned int') -> "bool":
        """SetAtomsElement(OESurface self, unsigned int n, unsigned int value) -> bool"""
        return _oespicoli.OESurface_SetAtomsElement(self, n, value)


    def IsColorSet(self) -> "bool":
        """IsColorSet(OESurface self) -> bool"""
        return _oespicoli.OESurface_IsColorSet(self)


    def GetColor(self, *args) -> "bool":
        """
        GetColor(OESurface self, unsigned char * color) -> bool
        GetColor(OESurface self, float * color) -> bool
        """
        return _oespicoli.OESurface_GetColor(self, *args)


    def SetColor(self, *args) -> "bool":
        """
        SetColor(OESurface self, unsigned char const * color) -> bool
        SetColor(OESurface self, float const * color) -> bool
        """
        return _oespicoli.OESurface_SetColor(self, *args)


    def SetColorElement(self, *args) -> "bool":
        """
        SetColorElement(OESurface self, unsigned int n, unsigned char r, unsigned char g, unsigned char b, unsigned char a=255) -> bool
        SetColorElement(OESurface self, unsigned int n, unsigned char r, unsigned char g, unsigned char b) -> bool
        SetColorElement(OESurface self, unsigned int n, float r, float g, float b, float a=1.0) -> bool
        SetColorElement(OESurface self, unsigned int n, float r, float g, float b) -> bool
        """
        return _oespicoli.OESurface_SetColorElement(self, *args)


    def IsVertexCliqueSet(self) -> "bool":
        """IsVertexCliqueSet(OESurface self) -> bool"""
        return _oespicoli.OESurface_IsVertexCliqueSet(self)


    def GetVertexClique(self, vertexClique: 'unsigned int *') -> "bool":
        """GetVertexClique(OESurface self, unsigned int * vertexClique) -> bool"""
        return _oespicoli.OESurface_GetVertexClique(self, vertexClique)


    def GetVertexCliqueElement(self, n: 'unsigned int') -> "unsigned int":
        """GetVertexCliqueElement(OESurface self, unsigned int n) -> unsigned int"""
        return _oespicoli.OESurface_GetVertexCliqueElement(self, n)


    def SetVertexClique(self, vertexClique: 'unsigned int const *') -> "bool":
        """SetVertexClique(OESurface self, unsigned int const * vertexClique) -> bool"""
        return _oespicoli.OESurface_SetVertexClique(self, vertexClique)


    def SetVertexCliqueElement(self, n: 'unsigned int', value: 'unsigned int') -> "bool":
        """SetVertexCliqueElement(OESurface self, unsigned int n, unsigned int value) -> bool"""
        return _oespicoli.OESurface_SetVertexCliqueElement(self, n, value)


    def ClearVertexClique(self) -> "bool":
        """ClearVertexClique(OESurface self) -> bool"""
        return _oespicoli.OESurface_ClearVertexClique(self)


    def GetVerticesElement(self, n: 'unsigned int') -> "float":
        """GetVerticesElement(OESurface self, unsigned int n) -> float"""
        return _oespicoli.OESurface_GetVerticesElement(self, n)


    def SetVerticesElement(self, n: 'unsigned int', value: 'float') -> "bool":
        """SetVerticesElement(OESurface self, unsigned int n, float value) -> bool"""
        return _oespicoli.OESurface_SetVerticesElement(self, n, value)


    def GetTrianglesElement(self, n: 'unsigned int') -> "unsigned int":
        """GetTrianglesElement(OESurface self, unsigned int n) -> unsigned int"""
        return _oespicoli.OESurface_GetTrianglesElement(self, n)


    def SetTrianglesElement(self, n: 'unsigned int', value: 'unsigned int') -> "bool":
        """SetTrianglesElement(OESurface self, unsigned int n, unsigned int value) -> bool"""
        return _oespicoli.OESurface_SetTrianglesElement(self, n, value)


    def GetNormalsElement(self, n: 'unsigned int') -> "float":
        """GetNormalsElement(OESurface self, unsigned int n) -> float"""
        return _oespicoli.OESurface_GetNormalsElement(self, n)


    def SetNormalsElement(self, n: 'unsigned int', value: 'float') -> "bool":
        """SetNormalsElement(OESurface self, unsigned int n, float value) -> bool"""
        return _oespicoli.OESurface_SetNormalsElement(self, n, value)


    def GetFaceNormalsElement(self, n: 'unsigned int') -> "float":
        """GetFaceNormalsElement(OESurface self, unsigned int n) -> float"""
        return _oespicoli.OESurface_GetFaceNormalsElement(self, n)


    def SetFaceNormalsElement(self, n: 'unsigned int', value: 'float') -> "bool":
        """SetFaceNormalsElement(OESurface self, unsigned int n, float value) -> bool"""
        return _oespicoli.OESurface_SetFaceNormalsElement(self, n, value)


    def Sweep(self) -> "void":
        """Sweep(OESurface self)"""
        return _oespicoli.OESurface_Sweep(self)


    def GetVertex(self, *args) -> "PyObject *":
        """
        GetVertex(OESurface self, unsigned int n, float * vertex) -> bool
        GetVertex(OESurface self, unsigned int n) -> PyObject *
        """
        return _oespicoli.OESurface_GetVertex(self, *args)


    def SetVertex(self, *args) -> "PyObject *":
        """
        SetVertex(OESurface self, unsigned int n, float const * vertex) -> bool
        SetVertex(OESurface self, unsigned int n, PyObject * input) -> PyObject *
        """
        return _oespicoli.OESurface_SetVertex(self, *args)


    def GetTriangle(self, *args) -> "PyObject *":
        """
        GetTriangle(OESurface self, unsigned int n, unsigned int * triangle) -> bool
        GetTriangle(OESurface self, unsigned int n) -> PyObject *
        """
        return _oespicoli.OESurface_GetTriangle(self, *args)


    def SetTriangle(self, *args) -> "PyObject *":
        """
        SetTriangle(OESurface self, unsigned int n, unsigned int const * triangle) -> bool
        SetTriangle(OESurface self, unsigned int n, PyObject * input) -> PyObject *
        """
        return _oespicoli.OESurface_SetTriangle(self, *args)


    def GetNormal(self, *args) -> "PyObject *":
        """
        GetNormal(OESurface self, unsigned int n, float * normal) -> bool
        GetNormal(OESurface self, unsigned int n) -> PyObject *
        """
        return _oespicoli.OESurface_GetNormal(self, *args)


    def SetNormal(self, *args) -> "PyObject *":
        """
        SetNormal(OESurface self, unsigned int n, float const * normal) -> bool
        SetNormal(OESurface self, unsigned int n, PyObject * input) -> PyObject *
        """
        return _oespicoli.OESurface_SetNormal(self, *args)


    def GetFaceNormal(self, *args) -> "PyObject *":
        """
        GetFaceNormal(OESurface self, unsigned int n, float * normal) -> bool
        GetFaceNormal(OESurface self, unsigned int n) -> PyObject *
        """
        return _oespicoli.OESurface_GetFaceNormal(self, *args)


    def SetFaceNormal(self, *args) -> "PyObject *":
        """
        SetFaceNormal(OESurface self, unsigned int n, float const * normal) -> bool
        SetFaceNormal(OESurface self, unsigned int n, PyObject * input) -> PyObject *
        """
        return _oespicoli.OESurface_SetFaceNormal(self, *args)


    def GetColorElement(self, n: 'unsigned int') -> "PyObject *":
        """GetColorElement(OESurface self, unsigned int n) -> PyObject *"""
        return _oespicoli.OESurface_GetColorElement(self, n)


    def GetColorElementF(self, n: 'unsigned int') -> "PyObject *":
        """GetColorElementF(OESurface self, unsigned int n) -> PyObject *"""
        return _oespicoli.OESurface_GetColorElementF(self, n)

OESurface_swigregister = _oespicoli.OESurface_swigregister
OESurface_swigregister(OESurface)


def OEGetSurfaceCenterAndExtents(surf: 'OESurface', center: 'float *', extents: 'float *') -> "void":
    """OEGetSurfaceCenterAndExtents(OESurface surf, float * center, float * extents)"""
    return _oespicoli.OEGetSurfaceCenterAndExtents(surf, center, extents)

def OESetSurface(obj: 'OEBase', t: 'char const *', s: 'OESurface') -> "bool":
    """OESetSurface(OEBase obj, char const * t, OESurface s) -> bool"""
    return _oespicoli.OESetSurface(obj, t, s)

def OEGetSurface(obj: 'OEBase', t: 'char const *') -> "OESpicoli::OESurface const &":
    """OEGetSurface(OEBase obj, char const * t) -> OESurface"""
    return _oespicoli.OEGetSurface(obj, t)

def OEMakeMolecularSurface(*args) -> "bool":
    """
    OEMakeMolecularSurface(OESurface surf, OEMolBase mol, float resolution=0.5, float probeRadius=1.4, unsigned int polygonizeMethod) -> bool
    OEMakeMolecularSurface(OESurface surf, OEMolBase mol, float resolution=0.5, float probeRadius=1.4) -> bool
    OEMakeMolecularSurface(OESurface surf, OEMolBase mol, float resolution=0.5) -> bool
    OEMakeMolecularSurface(OESurface surf, OEMolBase mol) -> bool
    OEMakeMolecularSurface(OESurface surf, float const * coords, float const * radii, int natoms, float resolution=0.5, float probeRadius=1.4, unsigned int polygonizeMethod) -> bool
    OEMakeMolecularSurface(OESurface surf, float const * coords, float const * radii, int natoms, float resolution=0.5, float probeRadius=1.4) -> bool
    OEMakeMolecularSurface(OESurface surf, float const * coords, float const * radii, int natoms, float resolution=0.5) -> bool
    OEMakeMolecularSurface(OESurface surf, float const * coords, float const * radii, int natoms) -> bool
    """
    return _oespicoli.OEMakeMolecularSurface(*args)

def OEMakeProteinRibbonSurface(*args) -> "bool":
    """
    OEMakeProteinRibbonSurface(OESurface surf, OEMolBase mol, unsigned int type) -> bool
    OEMakeProteinRibbonSurface(OESurface surf, OEMolBase mol) -> bool
    """
    return _oespicoli.OEMakeProteinRibbonSurface(*args)

def OEMakeAccessibleSurface(*args) -> "bool":
    """
    OEMakeAccessibleSurface(OESurface surf, OEMolBase mol, float resolution=0.5, float probeRadius=1.4, unsigned int polygonizeMethod) -> bool
    OEMakeAccessibleSurface(OESurface surf, OEMolBase mol, float resolution=0.5, float probeRadius=1.4) -> bool
    OEMakeAccessibleSurface(OESurface surf, OEMolBase mol, float resolution=0.5) -> bool
    OEMakeAccessibleSurface(OESurface surf, OEMolBase mol) -> bool
    OEMakeAccessibleSurface(OESurface surf, float const * coords, float const * radii, int natoms, float resolution=0.5, float probeRadius=1.4, unsigned int polygonizeMethod) -> bool
    OEMakeAccessibleSurface(OESurface surf, float const * coords, float const * radii, int natoms, float resolution=0.5, float probeRadius=1.4) -> bool
    OEMakeAccessibleSurface(OESurface surf, float const * coords, float const * radii, int natoms, float resolution=0.5) -> bool
    OEMakeAccessibleSurface(OESurface surf, float const * coords, float const * radii, int natoms) -> bool
    """
    return _oespicoli.OEMakeAccessibleSurface(*args)

def OEMakeSurfaceFromGrid(*args) -> "bool":
    """
    OEMakeSurfaceFromGrid(OESurface surf, OEFixedFloatGrid grid, float contour) -> bool
    OEMakeSurfaceFromGrid(OESurface surf, OEFixedFloatGrid grid, float contour, float resolution) -> bool
    OEMakeSurfaceFromGrid(OESurface surf, OESystem::OESkewGrid const & grid, float contour) -> bool
    """
    return _oespicoli.OEMakeSurfaceFromGrid(*args)

def OEMakeGridFromSurface(*args) -> "bool":
    """
    OEMakeGridFromSurface(OESystem::OEScalarGrid & grid, OESurface surf, unsigned int method) -> bool
    OEMakeGridFromSurface(OESystem::OEScalarGrid & grid, OESurface surf) -> bool
    """
    return _oespicoli.OEMakeGridFromSurface(*args)

def OEMakeBitGridFromSurface(*args) -> "bool":
    """
    OEMakeBitGridFromSurface(OESystem::OEScalarGrid & grid, OESurface surf, float spacing, float buffer) -> bool
    OEMakeBitGridFromSurface(OESystem::OEScalarGrid & grid, OESurface surf) -> bool
    """
    return _oespicoli.OEMakeBitGridFromSurface(*args)

def OEMakeVoidVolume(mol1: 'OEMolBase', mol2: 'OEMolBase', grid: 'OESystem::OEScalarGrid &', resolution: 'float', probeRad: 'float'=1.4) -> "bool":
    """
    OEMakeVoidVolume(OEMolBase mol1, OEMolBase mol2, OESystem::OEScalarGrid & grid, float resolution, float probeRad=1.4) -> bool
    OEMakeVoidVolume(OEMolBase mol1, OEMolBase mol2, OESystem::OEScalarGrid & grid, float resolution) -> bool
    """
    return _oespicoli.OEMakeVoidVolume(mol1, mol2, grid, resolution, probeRad)

def OEMakeComplexCavities(ligand: 'OEMolBase', protein: 'OEMolBase', surf: 'OESurface', resolution: 'float'=0.5, probeRad: 'float'=1.4) -> "bool":
    """
    OEMakeComplexCavities(OEMolBase ligand, OEMolBase protein, OESurface surf, float resolution=0.5, float probeRad=1.4) -> bool
    OEMakeComplexCavities(OEMolBase ligand, OEMolBase protein, OESurface surf, float resolution=0.5) -> bool
    OEMakeComplexCavities(OEMolBase ligand, OEMolBase protein, OESurface surf) -> bool
    """
    return _oespicoli.OEMakeComplexCavities(ligand, protein, surf, resolution, probeRad)

def OEMakeCavitySurfaces(mol: 'OEMolBase', surf: 'OESurface', resolution: 'float'=0.5, probeRadius: 'float'=1.4) -> "bool":
    """
    OEMakeCavitySurfaces(OEMolBase mol, OESurface surf, float resolution=0.5, float probeRadius=1.4) -> bool
    OEMakeCavitySurfaces(OEMolBase mol, OESurface surf, float resolution=0.5) -> bool
    OEMakeCavitySurfaces(OEMolBase mol, OESurface surf) -> bool
    """
    return _oespicoli.OEMakeCavitySurfaces(mol, surf, resolution, probeRadius)

def OESurfaceToMoleculeDistance(surf: 'OESurface', mol: 'OEMolBase') -> "bool":
    """OESurfaceToMoleculeDistance(OESurface surf, OEMolBase mol) -> bool"""
    return _oespicoli.OESurfaceToMoleculeDistance(surf, mol)

def OECalculateSurfaceCurvature(surf: 'OESurface', mol: 'OEMolBase', probeRadius: 'float'=1.4) -> "bool":
    """
    OECalculateSurfaceCurvature(OESurface surf, OEMolBase mol, float probeRadius=1.4) -> bool
    OECalculateSurfaceCurvature(OESurface surf, OEMolBase mol) -> bool
    """
    return _oespicoli.OECalculateSurfaceCurvature(surf, mol, probeRadius)

def OEMakeSphericalSurface(surf: 'OESurface', center: 'float *', radius: 'float', level: 'unsigned int'=4) -> "bool":
    """
    OEMakeSphericalSurface(OESurface surf, float * center, float radius, unsigned int level=4) -> bool
    OEMakeSphericalSurface(OESurface surf, float * center, float radius) -> bool
    """
    return _oespicoli.OEMakeSphericalSurface(surf, center, radius, level)

def OEMakeEllipsoidSurface(surf: 'OESurface', center: 'float *', a: 'float', b: 'float', c: 'float', dir1: 'float *', dir2: 'float *', dir3: 'float *', level: 'int'=4) -> "bool":
    """
    OEMakeEllipsoidSurface(OESurface surf, float * center, float a, float b, float c, float * dir1, float * dir2, float * dir3, int level=4) -> bool
    OEMakeEllipsoidSurface(OESurface surf, float * center, float a, float b, float c, float * dir1, float * dir2, float * dir3) -> bool
    """
    return _oespicoli.OEMakeEllipsoidSurface(surf, center, a, b, c, dir1, dir2, dir3, level)

def OEMakeBoxSurface(surf: 'OESurface', center: 'float const *', extents: 'float const *') -> "bool":
    """OEMakeBoxSurface(OESurface surf, float const * center, float const * extents) -> bool"""
    return _oespicoli.OEMakeBoxSurface(surf, center, extents)

def OECalculateFaceNormals(surf: 'OESurface') -> "bool":
    """OECalculateFaceNormals(OESurface surf) -> bool"""
    return _oespicoli.OECalculateFaceNormals(surf)

def OECalculateNormals(surf: 'OESurface') -> "bool":
    """OECalculateNormals(OESurface surf) -> bool"""
    return _oespicoli.OECalculateNormals(surf)

def OESetSurfacePotentials(surf: 'OESurface', grid: 'OESystem::OEScalarGrid const &') -> "bool":
    """OESetSurfacePotentials(OESurface surf, OESystem::OEScalarGrid const & grid) -> bool"""
    return _oespicoli.OESetSurfacePotentials(surf, grid)

def OESetSurfaceColor(*args) -> "bool":
    """
    OESetSurfaceColor(OESurface surf, unsigned char r, unsigned char g, unsigned char b, unsigned char a=255) -> bool
    OESetSurfaceColor(OESurface surf, unsigned char r, unsigned char g, unsigned char b) -> bool
    OESetSurfaceColor(OESurface surf, float r, float g, float b, float a=1.0) -> bool
    OESetSurfaceColor(OESurface surf, float r, float g, float b) -> bool
    """
    return _oespicoli.OESetSurfaceColor(*args)

def OEInvertSurface(surf: 'OESurface') -> "bool":
    """OEInvertSurface(OESurface surf) -> bool"""
    return _oespicoli.OEInvertSurface(surf)

def OESurfaceVolume(surf: 'OESurface') -> "float":
    """OESurfaceVolume(OESurface surf) -> float"""
    return _oespicoli.OESurfaceVolume(surf)

def OESurfaceArea(surf: 'OESurface') -> "float":
    """OESurfaceArea(OESurface surf) -> float"""
    return _oespicoli.OESurfaceArea(surf)

def OESurfaceCliqueVolume(surf: 'OESurface', clique: 'unsigned int') -> "float":
    """OESurfaceCliqueVolume(OESurface surf, unsigned int clique) -> float"""
    return _oespicoli.OESurfaceCliqueVolume(surf, clique)

def OESurfaceCliqueCentroid(surf: 'OESurface', clique: 'unsigned int', centroid: 'float *') -> "bool":
    """OESurfaceCliqueCentroid(OESurface surf, unsigned int clique, float * centroid) -> bool"""
    return _oespicoli.OESurfaceCliqueCentroid(surf, clique, centroid)

def OESurfaceCliqueArea(surf: 'OESurface', clique: 'unsigned int') -> "float":
    """OESurfaceCliqueArea(OESurface surf, unsigned int clique) -> float"""
    return _oespicoli.OESurfaceCliqueArea(surf, clique)

def OEMakeConnectedSurfaceCliques(surf: 'OESurface') -> "unsigned int":
    """OEMakeConnectedSurfaceCliques(OESurface surf) -> unsigned int"""
    return _oespicoli.OEMakeConnectedSurfaceCliques(surf)

def OECalculateTriangleAreas(surf: 'OESurface', areas: 'float *') -> "bool":
    """OECalculateTriangleAreas(OESurface surf, float * areas) -> bool"""
    return _oespicoli.OECalculateTriangleAreas(surf, areas)

def OESurfaceIsOpen(surf: 'OESurface') -> "bool":
    """OESurfaceIsOpen(OESurface surf) -> bool"""
    return _oespicoli.OESurfaceIsOpen(surf)

def OEMakeCliqueSurface(newsurf: 'OESurface', surf: 'OESurface', clique: 'unsigned int') -> "bool":
    """OEMakeCliqueSurface(OESurface newsurf, OESurface surf, unsigned int clique) -> bool"""
    return _oespicoli.OEMakeCliqueSurface(newsurf, surf, clique)

def OESurfaceCropToClique(surf: 'OESurface', clique: 'unsigned int') -> "bool":
    """OESurfaceCropToClique(OESurface surf, unsigned int clique) -> bool"""
    return _oespicoli.OESurfaceCropToClique(surf, clique)

def OEAddSurfaces(surf1: 'OESurface', surf2: 'OESurface') -> "bool":
    """OEAddSurfaces(OESurface surf1, OESurface surf2) -> bool"""
    return _oespicoli.OEAddSurfaces(surf1, surf2)

def OERotateSurface(surf: 'OESurface', rmat: 'float *') -> "void":
    """OERotateSurface(OESurface surf, float * rmat)"""
    return _oespicoli.OERotateSurface(surf, rmat)

def OETranslateSurface(surf: 'OESurface', trans: 'float *') -> "void":
    """OETranslateSurface(OESurface surf, float * trans)"""
    return _oespicoli.OETranslateSurface(surf, trans)

def OETransformSurface(surf: 'OESurface', trans: 'OETrans') -> "void":
    """OETransformSurface(OESurface surf, OETrans trans)"""
    return _oespicoli.OETransformSurface(surf, trans)

def OESplitSurfaceByAtoms(*args) -> "bool":
    """
    OESplitSurfaceByAtoms(OESurface newsurf, OESurface surf, OEMolBase mol, double maxDist=4.0) -> bool
    OESplitSurfaceByAtoms(OESurface newsurf, OESurface surf, OEMolBase mol) -> bool
    OESplitSurfaceByAtoms(OESurface surf, OEMolBase mol, double maxDist=4.0) -> bool
    OESplitSurfaceByAtoms(OESurface surf, OEMolBase mol) -> bool
    """
    return _oespicoli.OESplitSurfaceByAtoms(*args)

def OESmoothSurfaceEdges(surf: 'OESurface') -> "bool":
    """OESmoothSurfaceEdges(OESurface surf) -> bool"""
    return _oespicoli.OESmoothSurfaceEdges(surf)

_oespicoli.OE_OESPICOLI_VERSION_swigconstant(_oespicoli)
OE_OESPICOLI_VERSION = _oespicoli.OE_OESPICOLI_VERSION

def OESpicoliGetRelease() -> "char const *":
    """OESpicoliGetRelease() -> char const *"""
    return _oespicoli.OESpicoliGetRelease()

def OESpicoliGetVersion() -> "unsigned int":
    """OESpicoliGetVersion() -> unsigned int"""
    return _oespicoli.OESpicoliGetVersion()

def OESpicoliGetArch() -> "char const *":
    """OESpicoliGetArch() -> char const *"""
    return _oespicoli.OESpicoliGetArch()

def OESpicoliGetPlatform() -> "char const *":
    """OESpicoliGetPlatform() -> char const *"""
    return _oespicoli.OESpicoliGetPlatform()

def OESpicoliIsLicensed(feature: 'char const *'=None, expdate: 'unsigned int *'=None) -> "bool":
    """
    OESpicoliIsLicensed(char const * feature=None, unsigned int * expdate=None) -> bool
    OESpicoliIsLicensed(char const * feature=None) -> bool
    OESpicoliIsLicensed() -> bool
    """
    return _oespicoli.OESpicoliIsLicensed(feature, expdate)

def OESpicoliGetLicensee(*args) -> "std::string":
    """
    OESpicoliGetLicensee(std::string & licensee) -> bool
    OESpicoliGetLicensee() -> std::string
    """
    return _oespicoli.OESpicoliGetLicensee(*args)

def OESpicoliGetSite(*args) -> "std::string":
    """
    OESpicoliGetSite(std::string & site) -> bool
    OESpicoliGetSite() -> std::string
    """
    return _oespicoli.OESpicoliGetSite(*args)

def OEIsReadableSurface(*args) -> "bool":
    """
    OEIsReadableSurface(unsigned int type) -> bool
    OEIsReadableSurface(std::string const & filename) -> bool
    """
    return _oespicoli.OEIsReadableSurface(*args)

def OEIsWriteableSurface(*args) -> "bool":
    """
    OEIsWriteableSurface(unsigned int type) -> bool
    OEIsWriteableSurface(std::string const & filename) -> bool
    """
    return _oespicoli.OEIsWriteableSurface(*args)

def OEGetSurfaceFileType(ext: 'char const *') -> "unsigned int":
    """OEGetSurfaceFileType(char const * ext) -> unsigned int"""
    return _oespicoli.OEGetSurfaceFileType(ext)

def OEGetSurfaceFormatExtension(tag: 'unsigned int') -> "char const *":
    """OEGetSurfaceFormatExtension(unsigned int tag) -> char const *"""
    return _oespicoli.OEGetSurfaceFormatExtension(tag)

def OEGetSurfaceFormatString(tag: 'unsigned int') -> "char const *":
    """OEGetSurfaceFormatString(unsigned int tag) -> char const *"""
    return _oespicoli.OEGetSurfaceFormatString(tag)

def OEReadSurface(*args) -> "bool":
    """
    OEReadSurface(std::string const & fname, OESurface surf) -> bool
    OEReadSurface(oeistream ifs, OESurface surf, unsigned int type) -> bool
    """
    return _oespicoli.OEReadSurface(*args)

def OEWriteSurface(*args) -> "bool":
    """
    OEWriteSurface(std::string const & fname, OESurface surf) -> bool
    OEWriteSurface(oeostream ofs, OESurface surf, unsigned int type) -> bool
    """
    return _oespicoli.OEWriteSurface(*args)

def OEInitSurfaceHandlers(*args) -> "bool":
    """
    OEInitSurfaceHandlers(oemolstreambase fs)
    OEInitSurfaceHandlers(OEBinaryIOHandlerBase b) -> bool
    """
    return _oespicoli.OEInitSurfaceHandlers(*args)

def OEReduceSurface(*args) -> "bool":
    """
    OEReduceSurface(OESurface reducedSurface, OESurface original, unsigned int targetNumberOfVertices, unsigned int type) -> bool
    OEReduceSurface(OESurface reducedSurface, OESurface original, unsigned int targetNumberOfVertices) -> bool
    """
    return _oespicoli.OEReduceSurface(*args)

def OESurfaceToJSONBytes(*args) -> "PyObject *":
    """
    OESurfaceToJSONBytes(OESurface surf, unsigned int flavor) -> PyObject
    OESurfaceToJSONBytes(OESurface surf) -> PyObject *
    """
    return _oespicoli.OESurfaceToJSONBytes(*args)

def OEJSONToSurfaceBytes(surf: 'OESurface', bytes: 'PyObject *') -> "PyObject *":
    """OEJSONToSurfaceBytes(OESurface surf, PyObject * bytes) -> PyObject *"""
    return _oespicoli.OEJSONToSurfaceBytes(surf, bytes)





#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Perform reactions on the given compounds
#############################################################################
import sys
from openeye import oechem


def UniMolRxn(ifs, ofs, umr):
    for mol in ifs.GetOEGraphMols():
        if umr(mol):
            oechem.OEWriteMolecule(ofs, mol)


def main(argv=[__name__]):
    if not (3 <= len(argv) <= 4):
        oechem.OEThrow.Usage("%s SMIRKS <infile> [<outfile>]" % argv[0])

    qmol = oechem.OEQMol()
    if not oechem.OEParseSmirks(qmol, argv[1]):
        oechem.OEThrow.Fatal("Unable to parse SMIRKS: %s" % argv[1])

    umr = oechem.OEUniMolecularRxn()
    if not umr.Init(qmol):
        oechem.OEThrow.Fatal("Failed to initialize reaction with %s SMIRKS" % argv[1])
    umr.SetClearCoordinates(True)

    ifs = oechem.oemolistream()
    if not ifs.open(argv[2]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % argv[2])

    ofs = oechem.oemolostream(".ism")
    if len(argv) == 4:
        if not ofs.open(argv[3]):
            oechem.OEThrow.Fatal("Unable to open %s for writing" % argv[3])

    UniMolRxn(ifs, ofs, umr)


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
from __future__ import print_function
from openeye import oechem

# @ <SNIPPET-CREATE-ROLE-OBJECT>
role = oechem.OERole("my:analysis:active-site")
print(role.GetName())
# @ </SNIPPET-CREATE-ROLE-OBJECT>

# @ <SNIPPET-ADD-ROLE-OBJECT>
frag = oechem.OEAtomBondSet()  # isa OERoleSet
frag.AddRole(role)
# @ </SNIPPET-ADD-ROLE-OBJECT>

# @ <SNIPPET-ADD-ROLE-STRING>
frag.AddRole("my:analysis:low-energy")
# @ </SNIPPET-ADD-ROLE-STRING>

# @ <SNIPPET-HAS-ROLE-OBJECT>
role2 = oechem.OERole("my:analysis:low-energy")
print(frag.HasRole(role2))
# @ </SNIPPET-HAS-ROLE-OBJECT>

# @ <SNIPPET-HAS-ROLE-STRING>
print(frag.HasRole("my:analysis:small"))
# @ </SNIPPET-HAS-ROLE-STRING>

# @ <SNIPPET-HAS-ROLE-PRED>
pred = oechem.OEHasRole(role)
if pred(frag):
    print("has role: ", role.GetName())
# @ </SNIPPET-HAS-ROLE-PRED>

# @ <SNIPPET-GET-ALL-ROLES>
print([r.GetName() for r in frag.GetRoles()])
# @ </SNIPPET-GET-ALL-ROLES>

# @ <SNIPPET-DELETE-ROLE>
frag.DeleteRole(role)
frag.DeleteRole("my:analysis:some-role")
# @ </SNIPPET-DELETE-ROLE>

# @ <SNIPPET-DELETE-ALL-ROLES>
frag.ClearRoles()
# @ </SNIPPET-DELETE-ALL-ROLES>

# @ <SNIPPET-NUM-ROLES>
print(frag.NumRoles())
# @ </SNIPPET-NUM-ROLES>
# @ </SNIPPET>



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from __future__ import print_function
from openeye import oechem
from openeye import oemedchem
import sys


################################################################
# USED TO GENERATE CODE SNIPPETS FOR THE OEMEDCHEM DOCUMENTATION
# - please look at actual examples for useful utility code
################################################################


def FindSimpleMatchedPairs(itf):
    ims = oechem.oemolistream()
    if not ims.open(itf.GetString("-input")):
        oechem.OEThrow.Fatal("Unable to open %s for reading: " +
                             itf.GetString("-input"))

    maxrecs = itf.GetInt("-maxrec")

    oechem.OEThrow.SetLevel(oechem.OEErrorLevel_Warning)

    # @ <SNIPPET-FINDSIMPLEMATCHEDPAIRS-EXAMPLE>
    # create options class with defaults
    mmpOpts = oemedchem.OEMatchedPairAnalyzerOptions()

    # for 'simple' pairs, alter default indexing options
    # - single cuts only, heavy atom substituents only (HMember indexing off)
    mmpOpts.SetOptions(oemedchem.OEMatchedPairOptions_SingleCuts |
                       oemedchem.OEMatchedPairOptions_ComboCuts |
                       oemedchem.OEMatchedPairOptions_UniquesOnly)
    # - limit substituent size to no more than 20% of input structure
    mmpOpts.SetIndexableFragmentRange(80., 100.)

    # create analyzer class with nondefault options
    mmpAnalyzer = oemedchem.OEMatchedPairAnalyzer(mmpOpts)

    # ignore common index status returns
    sIgnoreStatus = 'FragmentRangeFilter,DuplicateStructure,'
    sIgnoreStatus += 'FragmentationLimitFilter,HeavyAtomFilter'

    # index the input structures
    for recindex, mol in enumerate(ims.GetOEGraphMols(), start=1):
        # consider only the largest input fragment
        oechem.OEDeleteEverythingExceptTheFirstLargestComponent(mol)
        # ignore stereochemistry
        oechem.OEUncolorMol(mol,
                            (oechem.OEUncolorStrategy_RemoveAtomStereo |
                             oechem.OEUncolorStrategy_RemoveBondStereo))

        # explicitly provide a 1-based index to refer to indexed structures
        #   - to allow references back to external data elsewhere
        status = mmpAnalyzer.AddMol(mol, recindex)
        if status != recindex:
            if not oemedchem.OEMatchedPairIndexStatusName(status) in sIgnoreStatus:
                oechem.OEThrow.Warning("{0}: molecule indexing error, status={1}"
                                       .format(recindex,
                                               oemedchem.OEMatchedPairIndexStatusName(status)))
        # if limiting input, quit after limit
        if maxrecs and recindex >= maxrecs:
            break

    print("Index complete, matched pairs = {0}"
          .format(mmpAnalyzer.NumMatchedPairs()))

    # specify how transforms are extracted (direction and allowed properties)
    extractMode = (oemedchem.OEMatchedPairTransformExtractMode_Sorted |
                   oemedchem.OEMatchedPairTransformExtractMode_NoSMARTS |
                   oemedchem.OEMatchedPairTransformExtractMode_AddMCSCorrespondence)

    extractOptions = oemedchem.OEMatchedPairTransformExtractOptions()
    # specify amount of chemical context at the site of the substituent change
    #   in the transform
    extractOptions.SetContext(oemedchem.OEMatchedPairContext_Bond0)
    extractOptions.SetOptions(extractMode)

    # walk the transforms and print the matched pairs
    xfmidx = 0
    for mmpxform in oemedchem.OEMatchedPairGetTransforms(mmpAnalyzer,
                                                         extractOptions):
        xfmidx += 1
        print("{0:2} {1}".format(xfmidx, mmpxform.GetTransform()))
        # dump matched molecular pairs and index identifiers
        #   (recindex from indexing loop above)
        for mmppair in mmpxform.GetMatchedPairs():
            print("\tmatched pair molecule indices=({0},{1})".format(mmppair.FromIndex(),
                                                                     mmppair.ToIndex()))
    # @ </SNIPPET-FINDSIMPLEMATCHEDPAIRS-EXAMPLE>

    return True


############################################################
InterfaceData = """
# FindSimpleMatchedPairs docexample
!CATEGORY FindSimpleMatchedPairs
    !CATEGORY I/O
        !PARAMETER -input 1
          !ALIAS -i
          !TYPE string
          !REQUIRED true
          !BRIEF Input filename of structures to analyze
          !KEYLESS 1
        !END

        !PARAMETER -output 2
          !ALIAS -o
          !TYPE string
          !BRIEF Output filename for simple pair transformations
        !END

        !PARAMETER -maxrec 3
          !TYPE int
          !DEFAULT 0
          !BRIEF Only process maxrec records from input file
        !END
    !END
!END
"""


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData, argv)
    FindSimpleMatchedPairs(itf)


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
from __future__ import print_function
from openeye import oechem
import sys

if len(sys.argv) != 2:
    oechem.OEThrow.Usage("%s <input>" % sys.argv[0])

ifs = oechem.oemolistream()
if not ifs.open(sys.argv[1]):
    oechem.OEThrow.Fatal("Unable to open %s" % sys.argv[1])

for mol in ifs.GetOEGraphMols():
    print(mol.NumAtoms())
    print(mol.GetTitle())

    coords = oechem.OEFloatArray(mol.GetMaxAtomIdx() * 3)
    mol.GetCoords(coords)

    for atom in mol.GetAtoms():
        idx = atom.GetIdx()
        syb = oechem.OEGetAtomicSymbol(atom.GetAtomicNum())

        print("%-3s%11.5f%11.5f%11.5f" % (syb,
                                          coords[idx * 3],
                                          coords[idx * 3 + 1],
                                          coords[idx * 3 + 2]))
# @ </SNIPPET>



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET-SETUP>
import sys
from openeye import oechem
from openeye import oeszmap
# @ </SNIPPET-SETUP>

InterfaceData = """
!BRIEF SzmapCalcs.py [-prob #.#] [-p] <molfile> [-l] <molfile> [-o] <molfile>
!PARAMETER -p
  !TYPE string
  !BRIEF Input protein (or other) context mol
  !REQUIRED true
  !KEYLESS 1
!END
!PARAMETER -l
  !TYPE string
  !BRIEF Input ligand coordinates for calculations
  !REQUIRED true
  !KEYLESS 2
!END
!PARAMETER -o
  !TYPE string
  !BRIEF Output file for points and probes molecules
  !REQUIRED true
  !KEYLESS 3
!END
!PARAMETER -prob
  !TYPE double
  !DEFAULT 0.5
  !BRIEF Cutoff for cumulative probability of probes
  !REQUIRED false
!END
"""


def RunSzmap(lig, prot):
    """
    run szmap at ligand coordinates in the protein context
    @rtype : None
    @param lig: mol defining coordinates for szmap calcs
    @param prot: context mol for szmap calcs (must have charges and radii)
    """

    # @ <SNIPPET-CREATE-SZMAPENGINEOPTIONS-OBJECT>
    opt = oeszmap.OESzmapEngineOptions()
    # @ </SNIPPET-CREATE-SZMAPENGINEOPTIONS-OBJECT>

    # @ <SNIPPET-GETPROBEMOL>
    mol = oechem.OEGraphMol()
    opt.GetProbeMol(mol)
    # @ </SNIPPET-GETPROBEMOL>
    print("probe mol smiles: %s" % oechem.OEMolToSmiles(mol))

    # @ <SNIPPET-SETPROBE>
    opt.SetProbe(360)
    # @ </SNIPPET-SETPROBE>
    print("norient = %d" % opt.NumOrientations())

    # @ <SNIPPET-COMBINE-OPTIONS>
    opt.SetProbe(24).SetMaskCutoff(999.99)
    # @ </SNIPPET-COMBINE-OPTIONS>
    print("norient = %d" % opt.NumOrientations())
    print("cutoff  = %.3f" % opt.GetMaskCutoff())

    opt.SetMaskCutoff(0.0)  # reset cutoff
    print("cutoff  = %.3f" % opt.GetMaskCutoff())

    # @ <SNIPPET-GET-PROBE>
    p = opt.GetProbe()
    print("probe nconf = %d" % p.NumConfs())
    # @ </SNIPPET-GET-PROBE>

    # @ <SNIPPET-CREATE-SZMAPENGINE-OBJECT>
    sz = oeszmap.OESzmapEngine(prot, opt)
    # @ </SNIPPET-CREATE-SZMAPENGINE-OBJECT>

    # @ <SNIPPET-GET-OPTIONS>
    opt = sz.GetOptions()
    print("norient= %d" % opt.NumOrientations())
    print("name   = %s" % opt.GetProbeName())
    print("cutoff = %.3f" % opt.GetMaskCutoff())
    # @ </SNIPPET-GET-OPTIONS>

    # @ <SNIPPET-GET-CONTEXT>
    mol = sz.GetContext()
    print("context mol: %s" % mol.GetTitle())
    # @ </SNIPPET-GET-CONTEXT>

    print("probe smiles: %s" % oechem.OEMolToSmiles(opt.GetProbe()))

    # @ <SNIPPET-CREATE-COORDSARRAY-OBJECT>
    coord = oechem.OEFloatArray(3)
    # @ </SNIPPET-CREATE-COORDSARRAY-OBJECT>

    # @ <SNIPPET-CREATE-SZMAPRESULTS-OBJECT>
    rslt = oeszmap.OESzmapResults()
    # @ </SNIPPET-CREATE-SZMAPRESULTS-OBJECT>

    for atom in lig.GetAtoms():
        lig.GetCoords(atom, coord)

        # @ <SNIPPET-GET-ENSEMBLE-NAME>
        name = oeszmap.OEGetEnsembleName(oeszmap.OEEnsemble_NeutralDiffDeltaG)
        # @ </SNIPPET-GET-ENSEMBLE-NAME>
        print("ensemble name: %s" % name)

        # @ <SNIPPET-GET-LONG-ENSEMBLE-NAME>
        longName = True
        name = oeszmap.OEGetEnsembleName(oeszmap.OEEnsemble_NeutralDiffDeltaG, longName)
        # @ </SNIPPET-GET-LONG-ENSEMBLE-NAME>
        # @ <SNIPPET-CALC-SZMAP-VALUE>
        nddg = oeszmap.OECalcSzmapValue(sz, coord)
        # @ </SNIPPET-CALC-SZMAP-VALUE>
        print("ensemble name: %s, value: %.3f" % (name, nddg))

        # @ <SNIPPET-GET-COMPONENT-NAME>
        name = oeszmap.OEGetComponentName(oeszmap.OEComponent_Interaction)
        # @ </SNIPPET-GET-COMPONENT-NAME>
        print("component name: %s" % name)

        # @ <SNIPPET-CLASH-RSLTS-EVAL>
        if not oeszmap.OEIsClashing(sz, coord):
            oeszmap.OECalcSzmapResults(rslt, sz, coord)
            nddg = rslt.GetEnsembleValue(oeszmap.OEEnsemble_NeutralDiffDeltaG)
            # @ </SNIPPET-CLASH-RSLTS-EVAL>

        # @ <SNIPPET-CALC-SZMAP-RESULTS>
        if not oeszmap.OEIsClashing(sz, coord):
            oeszmap.OECalcSzmapResults(rslt, sz, coord)
            # ...
            # @ </SNIPPET-CALC-SZMAP-RESULTS>

            print("result norient = %d" % rslt.NumOrientations())

            # @ <SNIPPET-GET-ENSEMBLE-VALUE>
            nddg = rslt.GetEnsembleValue(oeszmap.OEEnsemble_NeutralDiffDeltaG)
            # @ </SNIPPET-GET-ENSEMBLE-VALUE>
            print("nddG = %.3f" % nddg)
            print("vdw  = %.3f" % rslt.GetEnsembleValue(oeszmap.OEEnsemble_VDW))

            # @ <SNIPPET-GET-COMPONENT>
            coulomb = rslt.GetComponent(oeszmap.OEComponent_Interaction)
            print("interaction:")
            print(" ".join("%.3f" % c for c in coulomb))
            # @ </SNIPPET-GET-COMPONENT>

            # @ <SNIPPET-GET-ORDER>
            order = rslt.GetProbabilityOrder()
            print("conf with greatest prob = %d" % order[0])
            # @ </SNIPPET-GET-ORDER>

            # @ <SNIPPET-GET-PROBABILITIES>
            prob = rslt.GetProbabilities()
            print("greatest prob = %.3f" % prob[order[0]])
            # @ </SNIPPET-GET-PROBABILITIES>

            # @ <SNIPPET-GET-ORIENTATION-COMPONENT>
            vdw = oechem.OEDoubleArray(rslt.NumOrientations())
            rslt.GetComponent(vdw, oeszmap.OEComponent_VDW)
            print("vdw greatest prob = %.3f" % vdw[order[0]])
            # @ </SNIPPET-GET-ORIENTATION-COMPONENT>

            # @ <SNIPPET-GET-COORDS>
            point = oechem.OEFloatArray(3)
            rslt.GetCoords(point)
            # @ </SNIPPET-GET-COORDS>
            print("calc point: (%.3f, %.3f, %.3f)" % (point[0], point[1], point[2]))

            # @ <SNIPPET-PLACE-PROBE-SET-ALL>
            mcmol = oechem.OEMol()
            rslt.PlaceProbeSet(mcmol)
            # @ </SNIPPET-PLACE-PROBE-SET-ALL>

            # @ <SNIPPET-PLACE-PROBE-SET-PROB>
            probCutoff = 0.5
            rslt.PlaceProbeSet(mcmol, probCutoff)
            print("nconf to yield 50pct = %d" % mcmol.NumConfs())
            # @ </SNIPPET-PLACE-PROBE-SET-PROB>

            # @ <SNIPPET-PLACE-PROBE-SET-COUNT>
            clear = False
            cumulativeProb = rslt.PlaceProbeSet(mcmol, 10, clear)
            print("best 10 cumulative prob = %.3f" % cumulativeProb)
            # @ </SNIPPET-PLACE-PROBE-SET-COUNT>

            # @ <SNIPPET-PLACE-NEW-ATOM>
            amol = oechem.OEGraphMol()
            atom = rslt.PlaceNewAtom(amol)

            print("vdw = %s" % atom.GetData("vdw"))
            # @ </SNIPPET-PLACE-NEW-ATOM>

            # @ <SNIPPET-PLACE-PROBE-MOL>
            pmol = oechem.OEGraphMol()
            rslt.PlaceProbeMol(pmol, order[0])
            # @ </SNIPPET-PLACE-PROBE-MOL>


# @ <SNIPPET-GET-SZMAP-ENERGIES>
def GetSzmapEnergies(lig, prot):
    """
    run szmap at ligand coordinates in the protein context
    @rtype : None
    @param lig: mol defining coordinates for szmap calcs
    @param prot: context mol for szmap calcs (must have charges and radii)
    """

    print("num\tatom\t%s\t%s\t%s\t%s\t%s"
          % (oeszmap.OEGetEnsembleName(oeszmap.OEEnsemble_NeutralDiffDeltaG),
             oeszmap.OEGetEnsembleName(oeszmap.OEEnsemble_PSolv),
             oeszmap.OEGetEnsembleName(oeszmap.OEEnsemble_WSolv),
             oeszmap.OEGetEnsembleName(oeszmap.OEEnsemble_VDW),
             oeszmap.OEGetEnsembleName(oeszmap.OEEnsemble_OrderParam)))

    coord = oechem.OEFloatArray(3)

    sz = oeszmap.OESzmapEngine(prot)
    rslt = oeszmap.OESzmapResults()

    for i, atom in enumerate(lig.GetAtoms()):
        lig.GetCoords(atom, coord)

        if not oeszmap.OEIsClashing(sz, coord):
            oeszmap.OECalcSzmapResults(rslt, sz, coord)

            print("%2d\t%s\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f"
                  % (i, atom.GetName(),
                     rslt.GetEnsembleValue(oeszmap.OEEnsemble_NeutralDiffDeltaG),
                     rslt.GetEnsembleValue(oeszmap.OEEnsemble_PSolv),
                     rslt.GetEnsembleValue(oeszmap.OEEnsemble_WSolv),
                     rslt.GetEnsembleValue(oeszmap.OEEnsemble_VDW),
                     rslt.GetEnsembleValue(oeszmap.OEEnsemble_OrderParam)))
        else:
            print("%2d\t%s CLASH" % (i, atom.GetName()))
# @ </SNIPPET-GET-SZMAP-ENERGIES>


# @ <SNIPPET-GENERATE-SZMAP-PROBES>
def GenerateSzmapProbes(oms, cumulativeProb, lig, prot):
    """
    generate multiconf probes and data-rich points at ligand coords
    @rtype : None
    @param oms: output mol stream for points and probes
    @param cumulativeProb: cumulative probability for cutoff of point set
    @param lig: mol defining coordinates for szmap calcs
    @param prot: context mol for szmap calcs (must have charges and radii)
    """

    coord = oechem.OEFloatArray(3)

    sz = oeszmap.OESzmapEngine(prot)
    rslt = oeszmap.OESzmapResults()

    points = oechem.OEGraphMol()
    points.SetTitle("points %s" % lig.GetTitle())

    probes = oechem.OEMol()

    for i, atom in enumerate(lig.GetAtoms()):
        lig.GetCoords(atom, coord)

        if not oeszmap.OEIsClashing(sz, coord):
            oeszmap.OECalcSzmapResults(rslt, sz, coord)

            rslt.PlaceNewAtom(points)

            clear = False
            rslt.PlaceProbeSet(probes, cumulativeProb, clear)

    oechem.OEWriteMolecule(oms, points)
    oechem.OEWriteMolecule(oms, probes)
# @ </SNIPPET-GENERATE-SZMAP-PROBES>


def main(argv=(__name__)):
    """
    the protein should have charges and radii but the ligand need not
    """
    itf = oechem.OEInterface()

    if not oechem.OEConfigure(itf, InterfaceData):
        oechem.OEThrow.Fatal("Problem configuring OEInterface!")

    if not oechem.OEParseCommandLine(itf, argv):
        oechem.OEThrow.Fatal("Unable to parse command line")

    ligFile = itf.GetString("-l")
    ims = oechem.oemolistream()
    if not ims.open(ligFile):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % ligFile)
    lig = oechem.OEGraphMol()
    oechem.OEReadMolecule(ims, lig)

    contextFile = itf.GetString("-p")
    ims = oechem.oemolistream()
    if not ims.open(contextFile):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % contextFile)
    prot = oechem.OEGraphMol()
    oechem.OEReadMolecule(ims, prot)

    RunSzmap(lig, prot)

    GetSzmapEnergies(lig, prot)

    outputFile = itf.GetString("-o")
    oms = oechem.oemolostream()
    if not oms.open(outputFile):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % outputFile)

    GenerateSzmapProbes(oms, itf.GetDouble("-prob"), lig, prot)


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from __future__ import print_function
import os
import sys
import socket

try:
    from xmlrpclib import ServerProxy
except ImportError:  # python 3
    from xmlrpc.client import ServerProxy

from time import sleep

from openeye import oechem

oepy = os.path.join(os.path.dirname(__file__), "..", "python")
sys.path.insert(0, os.path.realpath(oepy))

InterfaceData = """\
!BRIEF [-blocking] [-h] <server:port>
!PARAMETER -host
  !ALIAS -h
  !TYPE string
  !REQUIRED true
  !BRIEF The host to check to see if it is up yet
  !KEYLESS 1
!END
!PARAMETER -blocking
  !ALIAS -b
  !TYPE bool
  !DEFAULT false
  !BRIEF If true the program will not exit until the database has finished loading.
!END
!PARAMETER -retries
  !ALIAS -r
  !TYPE int
  !DEFAULT 10
  !BRIEF Number of times to try connecting to the server.
!END
!PARAMETER -timeout
  !ALIAS -t
  !TYPE float
  !DEFAULT 60.0
  !BRIEF The time between retries is the timeout divided by the number of retries.
!END
"""


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData, argv)

    host = itf.GetString("-host")
    s = ServerProxy("http://" + host)

    blocking = itf.GetBool("-blocking")
    retries = itf.GetInt("-retries")
    if retries < 1:
        oechem.OEThrow.Fatal("-retries must be greater than 0")
    timeout = itf.GetFloat("-timeout")
    if timeout <= 0.0:
        oechem.OEThrow.Fatal("-timeout must be greater than 0.0")
    waittime = timeout/retries
    loaded = False
    while retries:
        try:
            loaded = s.IsLoaded(blocking)
            break
        except socket.error:
            retries -= 1
            if retries:
                print("Unable to connect to %s, retrying in %2.1f seconds" % (host, waittime))
                sleep(waittime)

    if not retries:
        print("Was never able to connect to a server, exiting...")
        return -1

    if loaded:
        loaded = "True"
    else:
        loaded = "False"

    print(host, "IsLoaded =", loaded)

    if loaded:
        return 0

    return 1


if __name__ == '__main__':
    sys.exit(main(sys.argv))



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Align two compounds based on the clique match
#############################################################################
import sys
from openeye import oechem


def CliqueAlign(refmol, fitmol, ofs):
    cs = oechem.OECliqueSearch(refmol, oechem.OEExprOpts_DefaultAtoms, oechem.OEExprOpts_DefaultBonds)
    cs.SetSaveRange(5)
    cs.SetMinAtoms(6)
    for mi in cs.Match(fitmol):
        rmat = oechem.OEDoubleArray(9)
        trans = oechem.OEDoubleArray(3)
        overlay = True
        oechem.OERMSD(cs.GetPattern(), fitmol, mi, overlay, rmat, trans)
        oechem.OERotate(fitmol, rmat)
        oechem.OETranslate(fitmol, trans)
        oechem.OEWriteMolecule(ofs, fitmol)


def main(argv=[__name__]):
    if len(argv) != 4:
        oechem.OEThrow.Usage("%s <refmol> <fitmol> <outfile>" % argv[0])

    reffs = oechem.oemolistream()
    if not reffs.open(argv[1]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % argv[1])
    if not oechem.OEIs3DFormat(reffs.GetFormat()):
        oechem.OEThrow.Fatal("Invalid input format: need 3D coordinates")
    refmol = oechem.OEGraphMol()
    if not oechem.OEReadMolecule(reffs, refmol):
        oechem.OEThrow.Fatal("Unable to read molecule in %s" % argv[1])
    if not refmol.GetDimension() == 3:
        oechem.OEThrow.Fatal("%s doesn't have 3D coordinates" % refmol.GetTitle())

    fitfs = oechem.oemolistream()
    if not fitfs.open(argv[2]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % argv[2])
    if not oechem.OEIs3DFormat(fitfs.GetFormat()):
        oechem.OEThrow.Fatal("Invalid input format: need 3D coordinates")

    ofs = oechem.oemolostream()
    if not ofs.open(argv[3]):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % argv[3])
    if not oechem.OEIs3DFormat(ofs.GetFormat()):
        oechem.OEThrow.Fatal("Invalid output format: need 3D coordinates")

    oechem.OEWriteConstMolecule(ofs, refmol)
    oechem.OESuppressHydrogens(refmol)

    for fitmol in fitfs.GetOEGraphMols():
        if not fitmol.GetDimension() == 3:
            oechem.OEThrow.Warning("%s doesn't have 3D coordinates" % fitmol.GetTitle())
            continue
        CliqueAlign(refmol, fitmol, ofs)


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict

# @ <SNIPPET-IMAGE-GRID-FIXED-SCALE>
smiles = ["c1ccccc1", "c1cccc2c1ccnc2", "c1ccc2c(c1)cc3ccccc3n2"]

molecules = []
for smi in smiles:
    mol = oechem.OEGraphMol()
    oechem.OESmilesToMol(mol, smi)
    oedepict.OEPrepareDepiction(mol)
    molecules.append(oechem.OEGraphMol(mol))

image = oedepict.OEImage(400, 200)

rows, cols = 1, 3
grid = oedepict.OEImageGrid(image, rows, cols)

opts = oedepict.OE2DMolDisplayOptions(grid.GetCellWidth(), grid.GetCellHeight(), oedepict.OEScale_AutoScale)

minscale = float("inf")
for mol in molecules:
    minscale = min(minscale, oedepict.OEGetMoleculeScale(mol, opts))

opts.SetScale(minscale)
for idx, cell in enumerate(grid.GetCells()):
    disp = oedepict.OE2DMolDisplay(molecules[idx], opts)
    oedepict.OERenderMolecule(cell, disp)

oedepict.OEWriteImage("ImageGridFixedScale.png", image)
# @ </SNIPPET-IMAGE-GRID-FIXED-SCALE>
oedepict.OEWriteImage("ImageGridFixedScale.pdf", image)



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Print protein-ligand interactions
#############################################################################
from __future__ import print_function
import sys

from openeye import oechem


def main(argv=[__name__]):

    itf = oechem.OEInterface()
    oechem.OEConfigure(itf, InterfaceData)
    oechem.OEConfigureSplitMolComplexOptions(itf, oechem.OESplitMolComplexSetup_LigName)

    if not oechem.OEParseCommandLine(itf, argv):
        return 1

    iname = itf.GetString("-complex")

    ifs = oechem.oemolistream()
    if not ifs.open(iname):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % iname)

    complexmol = oechem.OEGraphMol()
    if not oechem.OEReadMolecule(ifs, complexmol):
        oechem.OEThrow.Fatal("Unable to read molecule from %s" % iname)

    if not oechem.OEHasResidues(complexmol):
        oechem.OEPerceiveResidues(complexmol, oechem.OEPreserveResInfo_All)

    # Separate ligand and protein

    sopts = oechem.OESplitMolComplexOptions()
    oechem.OESetupSplitMolComplexOptions(sopts, itf)

    ligand = oechem.OEGraphMol()
    protein = oechem.OEGraphMol()
    water = oechem.OEGraphMol()
    other = oechem.OEGraphMol()

    pfilter = sopts.GetProteinFilter()
    wfilter = sopts.GetWaterFilter()
    sopts.SetProteinFilter(oechem.OEOrRoleSet(pfilter, wfilter))
    sopts.SetWaterFilter(oechem.OEMolComplexFilterFactory(oechem.OEMolComplexFilterCategory_Nothing))

    oechem.OESplitMolComplex(ligand, protein, water, other, complexmol, sopts)

    if ligand.NumAtoms() == 0:
        oechem.OEThrow.Fatal("Cannot separate complex!")

    # Perceive interactions

    asite = oechem.OEInteractionHintContainer(protein, ligand)
    if not oechem.OEIsValidActiveSite(asite):
        oechem.OEThrow.Fatal("Cannot initialize active site!")

    oechem.OEPerceiveInteractionHints(asite)

    print("Number of interactions:", asite.NumInteractions())
    for itype in oechem.OEGetActiveSiteInteractionHintTypes():
        numinters = asite.NumInteractions(oechem.OEHasInteractionHintType(itype))
        if numinters == 0:
            continue
        print("%d %s :" % (numinters, itype.GetName()))

        inters = [s for s in asite.GetInteractions(oechem.OEHasInteractionHintType(itype))]
        print("\n".join(sorted(GetInteractionString(s) for s in inters)))

    print("\nResidue interactions:")
    for res in oechem.OEGetResidues(asite.GetMolecule(oechem.OEProteinInteractionHintComponent())):
        PrintResidueInteractions(asite, res)

    print("\nLigand atom interactions:")
    for atom in asite.GetMolecule(oechem.OELigandInteractionHintComponent()).GetAtoms():
        PrintLigandAtomInteractions(asite, atom)


def GetResidueName(residue):
    return "%3s %4d %s" % (residue.GetName(), residue.GetResidueNumber(), residue.GetChainID())


def GetInteractionString(inter):

    fragstrs = []
    for frag in [inter.GetBgnFragment(), inter.GetEndFragment()]:
        if frag is None:
            continue
        fragtype = frag.GetComponentType()
        if fragtype == oechem.OELigandInteractionHintComponent():
            fragstrs.append("ligand:" + " ".join(sorted(str(a) for a in frag.GetAtoms())))
        if fragtype == oechem.OEProteinInteractionHintComponent():
            fragstrs.append("protein:" + " ".join(sorted(str(a) for a in frag.GetAtoms())))

    return " ".join(sorted(f for f in fragstrs))


def PrintResidueInteractions(asite, residue):

    ligatomnames = set()
    for inter in asite.GetInteractions(oechem.OEHasResidueInteractionHint(residue)):
        ligfrag = inter.GetFragment(oechem.OELigandInteractionHintComponent())
        if ligfrag is None:
            continue
        for latom in ligfrag.GetAtoms():
            ligatomnames.add(str(latom))

    if len(ligatomnames) != 0:
        print(GetResidueName(residue), ": ", " ".join(sorted(a for a in ligatomnames)))


def PrintLigandAtomInteractions(asite, atom):

    resnames = set()
    for inter in asite.GetInteractions(oechem.OEHasInteractionHint(atom)):
        profrag = inter.GetFragment(oechem.OEProteinInteractionHintComponent())
        if profrag is None:
            continue
        for patom in profrag.GetAtoms():
            residue = oechem.OEAtomGetResidue(patom)
            resnames.add(GetResidueName(residue))

    if len(resnames) != 0:
        print(atom, ":", " ".join(sorted(r for r in resnames)))


InterfaceData = '''
!BRIEF printinteractions [-complex] <input>

!CATEGORY "input/output options :"

  !PARAMETER -complex
    !ALIAS -c
    !TYPE string
    !KEYLESS 1
    !REQUIRED true
    !VISIBILITY simple
    !BRIEF Input filename of the protein complex
  !END

!END
'''

if __name__ == "__main__":
        sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys

from openeye import oechem
from openeye import oedocking


# @ <SNIPPET-POSEBEST-HELPER>
# Return the index of the best receptor for posing ligand
def BestReceptorIndex(ligand, receptors):
    best_idx = len(receptors) + 1
    best_probability = 0.0

    for receptor_index, receptor in enumerate(receptors):
        probability = oedocking.OEGetEstimatedPositProbability(ligand, receptor)
        if probability > best_probability:
            best_probability, best_idx = probability, receptor_index

    return best_idx
# @ </SNIPPET-POSEBEST-HELPER>


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData)
    if not oechem.OEParseCommandLine(itf, argv):
        return 1

    # @ <SNIPPET-POSEBEST-MOLECULES-READRECEPTORS>
    receptors = []
    for receptor_filename in itf.GetStringList("-receptors"):
        receptor = oechem.OEGraphMol()
        if not oedocking.OEReadReceptorFile(receptor, receptor_filename):
            oechem.OEThrow.Fatal("Unable to read receptor from %s" %
                                 receptor_filename)
        receptors.append(receptor)
    # @ </SNIPPET-POSEBEST-MOLECULES-READRECEPTORS>

    # @ <SNIPPET-POSEBEST-MOLECULES-SETUP>
    poser = oedocking.OEPosit()
    # @ </SNIPPET-POSEBEST-MOLECULES-SETUP>

    # Identify the best receptors
    imstr = oechem.oemolistream()
    if not imstr.open(itf.GetString("-in")):
        oechem.OEThrow.Fatal("Could not open %s for reading", itf.GetString("-in"))
    mcmol = oechem.OEMol()
    ligand_number = 0
    bestReceptorIdx = {}
    while oechem.OEReadMolecule(imstr, mcmol):
        bestReceptorIdx[ligand_number] = BestReceptorIndex(mcmol, receptors)
        ligand_number += 1
    imstr.close()

    # Loop through all the receptors and pose molecules
    for receptor_idx, receptor in enumerate(receptors):
        # write out a new output file for each receptor
        #  <prefix>_#.oeb.gz

        omstr = oechem.oemolostream("%s_%s.oeb" % (itf.GetString("-prefix"),
                                    receptor_idx))
        poser.Initialize(receptor)

        imstr = oechem.oemolistream()
        if not imstr.open(itf.GetString("-in")):
            oechem.OEThrow.Fatal("Could not open %s for reading", itf.GetString("-in"))

        ligand_number = 0
        # @ <SNIPPET-POSEBEST-CHOOSEBEST>
        while oechem.OEReadMolecule(imstr, mcmol):
            #  is the current receptor the best one?
            if receptor_idx == bestReceptorIdx[ligand_number]:
                oechem.OEThrow.Info("Posing ligand %s(%d) to receptor %s(%d)"
                                    % (mcmol.GetTitle(), ligand_number,
                                       receptor.GetTitle(), receptor_idx))

                posedMol = oechem.OEGraphMol()
                poser.DockMultiConformerMolecule(posedMol, mcmol)

                oedocking.OESetSDScore(posedMol, poser, poser.GetName())
                oechem.OEWriteMolecule(omstr, posedMol)
            ligand_number += 1
        # @ </SNIPPET-POSEBEST-CHOOSEBEST>

    return 0


InterfaceData = """
# Begin the definition of the -receptor command line parameter.
!PARAMETER -receptors

  # allows the use of -rec on the command as a shortcut for -receptors
  !ALIAS -rec

  # Parameter is a of type string
  !TYPE string

  # parameter can support multiple receptors ala
  #  -receptors *.oeb.gz
  !LIST true

  # Tells the OEParseCommandLine function to throw an error if this
  # parameter isn't specified on the command line
  !REQUIRED true

  # Specifies that only strings ending in .oeb or .oeb.gz are legal
  # settings for this parameter (OEParseCommandLine will throw an error)
  !LEGAL_VALUE *.oeb
  !LEGAL_VALUE *.oeb.gz

  # Description of the parameter (accessible by the users via --help command)
  !BRIEF A receptor file the molecules pass to the -in flag will be posed to

# End the definition of -receptor parameter
!END


# Begin definition of -in command line parameter
!PARAMETER -in

  # Parameter is of type string
  !TYPE string

  # Parameter must be specified on the command line or OEParseCommandLine
  # function will throw an error.
  !REQUIRED true

  # Description of the parameter (accessible by the users via --help command)
  !BRIEF Multiconformer file of molecules to be posed.

# End of the definition of -in
!END


# Begin definition of -prefix command line parameter
!PARAMETER -prefix

  # Parameter is of type string
  !TYPE string

  # Parameter must be specified on the command line or OEParseCommandLine
  # function will throw an error.
  !REQUIRED true

  # Description of the parameter (accessible by the users via --help command)
  !BRIEF Posed molecules will be written to this file using this prefix <prefix>_<receptor#>.oeb

# End of the definition of -prefix
!END
"""

if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Extract properties from SD file and save as CSV
#############################################################################
import sys
from openeye import oechem


def SDF2CSV(ifs, csv):
    taglist = []
    # read through once to find all unique tags
    for mol in ifs.GetOEGraphMols():
        for dp in oechem.OEGetSDDataPairs(mol):
            if dp.GetTag() not in taglist:
                taglist.append(dp.GetTag())

    ifs.rewind()
    # print out column labels
    header = "Title"
    for tag in taglist:
        header += ",%s" % tag
    header += '\n'
    csv.write(header)

    # build csv file
    for mol in ifs.GetOEGraphMols():
        line = [mol.GetTitle()]
        for tag in taglist:
            if oechem.OEHasSDData(mol, tag):
                value = oechem.OEGetSDData(mol, tag)
            else:
                value = ''
            line.append(',')
            line.append(value)
        csv.write(''.join(line))
        csv.write('\n')


def main(argv=[__name__]):
    if len(argv) != 3:
        oechem.OEThrow.Usage("%s <infile> <csvfile>" % argv[0])

    ifs = oechem.oemolistream()
    if not ifs.open(argv[1]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % argv[1])
    if ifs.GetFormat() not in [oechem.OEFormat_SDF, oechem.OEFormat_OEB]:
        oechem.OEThrow.Fatal("Only works for sdf or oeb input files")

    csv = oechem.oeofstream()
    if not csv.open(argv[2]):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % argv[2])

    SDF2CSV(ifs, csv)


if __name__ == '__main__':
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict
from openeye import oegrapheme


# @ <SNIPPET-DRAW-MULTIPLE-2D-SURFACES>
def Draw2DSurface(disp, atompred, radius, color):

    penA = oedepict.OEPen(color, color, oedepict.OEFill_Off, 2.0)
    arcfxnA = oegrapheme.OEDefaultArcFxn(penA)

    penB = oedepict.OEPen(oechem.OELightGrey, oechem.OELightGrey, oedepict.OEFill_Off, 2.0,
                          oedepict.OEStipple_ShortDash)
    arcfxnB = oegrapheme.OEDefaultArcFxn(penB)

    layer = disp.GetLayer(oedepict.OELayerPosition_Below)

    for adisp in disp.GetAtomDisplays():
        for arc in oegrapheme.OEGet2DSurfaceArcs(disp, adisp, radius):
            if atompred(adisp.GetAtom()):
                arcfxnA(layer, arc)
            else:
                arcfxnB(layer, arc)


def Draw2DSurfaces(image, mol):

    oedepict.OEPrepareDepiction(mol)

    opts = oedepict.OE2DMolDisplayOptions(image.GetWidth(), image.GetHeight(), oedepict.OEScale_AutoScale)
    opts.SetTitleLocation(oedepict.OETitleLocation_Hidden)
    opts.SetScale(oegrapheme.OEGetMoleculeSurfaceScale(mol, opts, 1.50))

    disp = oedepict.OE2DMolDisplay(mol, opts)

    Draw2DSurface(disp, oechem.OEHasAtomicNum(oechem.OEElemNo_C), 1.00, oechem.OEBlack)
    Draw2DSurface(disp, oechem.OEHasAtomicNum(oechem.OEElemNo_N), 1.25, oechem.OEDarkBlue)
    Draw2DSurface(disp, oechem.OEHasAtomicNum(oechem.OEElemNo_O), 1.50, oechem.OEDarkRed)

    oedepict.OERenderMolecule(image, disp)
# @ </SNIPPET-DRAW-MULTIPLE-2D-SURFACES>


mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "c1cc(N)ccc1O")

imagewidth, imageheight = 300.0, 260.0
image = oedepict.OEImage(imagewidth, imageheight)
Draw2DSurfaces(image, mol)

oedepict.OEWriteImage("DrawMultiple2DSurfaces.png", image)
oedepict.OEWriteImage("DrawMultiple2DSurfaces.pdf", image)



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

###############################################################################
# Utility to load a pregenerated index and return the highest MCS similarity
#  structures from an query structure(s)
# ---------------------------------------------------------------------------
# MCSFragDatabase [ -indb index.mcsfrag ]
#                 [ -query query_file ]
#                 [ -type bond -limit 10 ]    // 10 Tanimoto sim bond scores
#                 [ -verbose 1 ]              // optional verbosity
#
# index.mcsfrag: filename of index file to load
# query_file: filename of query to report MCS similarity results
###############################################################################
from __future__ import print_function
from openeye import oechem
from openeye import oemedchem
import sys


def MCSFragQuery(itf):

    verbose = itf.GetBool("-verbose")
    timer = itf.GetBool("-timer")

    indb = itf.GetString("-indb")
    if not oemedchem.OEIsMCSFragDatabaseFileType(indb):
        oechem.OEThrow.Fatal("Option -indb must specify a .mcsfrag filename: "
                             + indb)
    if verbose:
        oechem.OEThrow.Info("Loading index from " + indb)

    watch = oechem.OEStopwatch()
    watch.Start()
    mcsdb = oemedchem.OEMCSFragDatabase()
    if not oemedchem.OEReadMCSFragDatabase(indb, mcsdb):
        oechem.OEThrow.Fatal("Error deserializing MCS fragment database: "
                             + indb)
    loadtime = watch.Elapsed()

    if not mcsdb.NumMols():
        oechem.OEThrow.Fatal("Loaded empty index")

    if timer:
        if not loadtime:
            oechem.OEThrow.Info("Loaded index of {0} molecules, {1} fragments"
                                .format(mcsdb.NumMols(), mcsdb.NumFragments()))
        else:
            oechem.OEThrow.Info("Loaded index of {0} molecules, {1} "
                                "fragments in {2:.2F} sec: "
                                "{3:,.1F} mols/sec {4:,.1F} frags/sec"
                                .format(mcsdb.NumMols(),
                                        mcsdb.NumFragments(),
                                        loadtime,
                                        float(mcsdb.NumMols())/loadtime,
                                        float(mcsdb.NumFragments())/loadtime))

    if not mcsdb.NumFragments():
        oechem.OEThrow.Fatal("No fragments loaded from index, "
                             "use -fragGe,-fragLe options to "
                             "extend indexable range")

    queryfile = itf.GetString("-query")
    ifsquery = oechem.oemolistream()
    if not ifsquery.open(queryfile):
        oechem.OEThrow.Fatal("Unable to open query file: " + queryfile)

    # process the query options
    qmaxrec = 0
    if itf.HasInt("-qlim"):
        qmaxrec = itf.GetInt("-qlim")

    numscores = 10
    if itf.HasInt("-limit"):
        numscores = itf.GetInt("-limit")

    cnttype = oemedchem.OEMCSScoreType_BondCount
    if itf.HasString("-type"):
        if "atom" in itf.GetString("-type"):
            cnttype = oemedchem.OEMCSScoreType_AtomCount
        elif "bond" in itf.GetString("-type"):
            cnttype = oemedchem.OEMCSScoreType_BondCount
        else:
            oechem.OEThrow.Warning("Ignoring unrecognized -type option, "
                                   "expecting atom or bond: " +
                                   itf.GetString("-type"))

    cntname = "bond"
    if cnttype != oemedchem.OEMCSScoreType_BondCount:
        cntname = "atom"

    # process the query (or queries)
    qmol = oechem.OEGraphMol()
    qnum = 0
    while oechem.OEReadMolecule(ifsquery, qmol):
        qnum += 1

        numhits = 0
        for score in mcsdb.GetSortedScores(qmol,
                                           numscores,
                                           0,
                                           0,
                                           True,
                                           cnttype):
            if numhits == 0:
                oechem.OEThrow.Info("Query: {0}: {1}"
                                    .format(qnum, qmol.GetTitle()))

            oechem.OEThrow.Info("\trecord: {0:6}\ttanimoto_{1}_score: "
                                "{2:.2f}\tmcs_core: {3}"
                                .format(score.GetIdx(),
                                        cntname,
                                        score.GetScore(),
                                        score.GetMCSCore()))
            numhits += 1

        if numhits == 0:
            oechem.OEThrow.Warning("Query: {0}: {1} - no hits"
                                   .format(qnum, qmol.GetTitle()))

        if qmaxrec and qnum >= qmaxrec:
            break

    if qnum == 0:
        oechem.OEThrow.Fatal("Error reading query structure(s): " + queryfile)


############################################################
InterfaceData = """
#MCSFragmentDatabase interface file
!CATEGORY MCSFragmentDatabase

    !CATEGORY I/O
        !PARAMETER -indb 1
          !TYPE string
          !REQUIRED true
          !BRIEF Input filename of index file to load
          !KEYLESS 1
        !END

        !PARAMETER -query 2
          !ALIAS -q
          !TYPE string
          !REQUIRED true
          !BRIEF query structure file to report similarity results against
          !KEYLESS 2
        !END

    !END

    !CATEGORY options
        !PARAMETER -type 1
           !TYPE string
           !DEFAULT bond
           !BRIEF MCS core counts to use for reported scores: atom or bond
        !END
        !PARAMETER -limit 2
           !TYPE int
           !DEFAULT 10
           !BRIEF report -limit scores for the query structure
        !END
        !PARAMETER -verbose 3
           !TYPE bool
           !DEFAULT 0
           !BRIEF generate verbose output
        !END
        !PARAMETER -qlim 4
           !TYPE int
           !DEFAULT 0
           !BRIEF limit query processing to -qlim records from the -query structures
        !END
        !PARAMETER -timer 5
           !TYPE bool
           !DEFAULT 0
           !BRIEF report database loading time
        !END
    !END
!END
"""


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData)
    if not oechem.OEParseCommandLine(itf, argv):
        oechem.OEThrow.Fatal("Unable to interpret command line!")

    MCSFragQuery(itf)


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from __future__ import print_function
from __future__ import unicode_literals
import os
import sys
import argparse

try:
    from xmlrpclib import ServerProxy, Binary, Fault
except ImportError:  # python 3
    from xmlrpc.client import ServerProxy, Binary, Fault


class Pyasciigraph:
    """ Copied from https://pypi.python.org/pypi/ascii_graph/0.2.1 """
    def __init__(self, line_length=79, min_graph_length=50, separator_length=2):
        """Constructor of Pyasciigraph

        :param int line_length: the max number of char on a line
                if any line cannot be shorter,
                it will go over this limit
        :param int min_graph_length: the min number of char used by the graph
        :param int separator_length: the length of field separator
        """
        self.line_length = line_length
        self.separator_length = separator_length
        self.min_graph_length = min_graph_length

    def _u(self, x):
        if sys.version < '3':
            import codecs
            return codecs.unicode_escape_decode(x)[0]
        else:
            return x

    def _get_maximum(self, data):
        all_max = {}
        all_max['value_max_length'] = 0
        all_max['info_max_length'] = 0
        all_max['max_value'] = 0

        for (info, value) in data:
            if value > all_max['max_value']:
                all_max['max_value'] = value

            if len(info) > all_max['info_max_length']:
                all_max['info_max_length'] = len(info)

            if len(str(value)) > all_max['value_max_length']:
                all_max['value_max_length'] = len(str(value))
        return all_max

    def _gen_graph_string(self, value, max_value, graph_length, start_value):
        number_of_square = 0
        if max_value:
            number_of_square = int(value * graph_length / max_value)
        number_of_space = int(start_value - number_of_square)
        return '#' * number_of_square + self._u(' ') * number_of_space

    def _gen_info_string(self, info, start_info, line_length):
        number_of_space = (line_length - start_info - len(info))
        return info + self._u(' ') * number_of_space

    def _gen_value_string(self, value, start_value, start_info):
        number_space = start_info -\
                start_value -\
                len(str(value)) -\
                self.separator_length

        return ' ' * number_space +\
            str(value) +\
            ' ' * self.separator_length

    def _sanitize_string(self, string):
        # get the type of a unicode string
        unicode_type = type(self._u('t'))
        input_type = type(string)
        if input_type is str:
            info = string
        elif input_type is unicode_type:
            info = string
        elif input_type is int or input_type is float:
            info = str(string)
        return info

    def _sanitize_data(self, data):
        ret = []
        for item in data:
            ret.append((self._sanitize_string(item[0]), item[1]))
        return ret

    def graph(self, label, data, sort=0, with_value=True):
        """function generating the graph

        :param string label: the label of the graph
        :param iterable data: the data (list of tuple (info, value))
                info must be "castable" to a unicode string
                value must be an int or a float
        :param int sort: flag sorted
                0: not sorted (same order as given) (default)
                1: increasing order
                2: decreasing order
        :param boolean with_value: flag printing value
                True: print the numeric value (default)
                False: don't print the numeric value
        :rtype: a list of strings (each lines)

        """
        result = []
        san_data = self._sanitize_data(data)
        san_label = self._sanitize_string(label)

        if sort == 1:
            san_data = sorted(san_data, key=lambda value: value[1], reverse=False)
        elif sort == 2:
            san_data = sorted(san_data, key=lambda value: value[1], reverse=True)

        all_max = self._get_maximum(san_data)

        real_line_length = max(self.line_length, len(label))

        min_line_length = self.min_graph_length + 2 * self.separator_length +\
            all_max['value_max_length'] + all_max['info_max_length']

        if min_line_length < real_line_length:
            # calcul of where to start info
            start_info = self.line_length -\
                all_max['info_max_length']
            # calcul of where to start value
            start_value = start_info -\
                self.separator_length -\
                all_max['value_max_length']
            # calcul of where to end graph
            graph_length = start_value -\
                self.separator_length
        else:
            # calcul of where to start value
            start_value = self.min_graph_length +\
                self.separator_length
            # calcul of where to start info
            start_info = start_value +\
                all_max['value_max_length'] +\
                self.separator_length
            # calcul of where to end graph
            graph_length = self.min_graph_length
            # calcul of the real line length
            real_line_length = min_line_length

        result.append(san_label)
        result.append(self._u('#') * real_line_length)

        for item in san_data:
            info = item[0]
            value = item[1]

            graph_string = self._gen_graph_string(
                value,
                all_max['max_value'],
                graph_length,
                start_value
                )

            value_string = self._gen_value_string(
                value,
                start_value,
                start_info
                )

            info_string = self._gen_info_string(
                info,
                start_info,
                real_line_length
                )
            new_line = graph_string + value_string + info_string
            result.append(new_line)

        return result


def AddBin(bins, binSize, binIdx, curTotal):
    lowerBound = binSize * binIdx
    label = "%.2f" % lowerBound
    bins.append((label, curTotal))


def GetGraphTitle(tversky, shapeOnly):
    if not tversky and not shapeOnly:
        return "FastROCS Tanimoto Combo Score Distribution"
    if not tversky and shapeOnly:
        return "FastROCS Tanimoto Shape Score Distribution"
    if tversky and not shapeOnly:
        return "FastROCS Tversky Combo Score Distribution"
    if tversky and shapeOnly:
        return "FastROCS Tversky Shape Score Distribution"


def PrintHistogram(hist, tversky=None, shapeOnly=None):
    squashFactor = 10
    if shapeOnly:
        maxScore = 1.0
    else:
        maxScore = 2.0
    binSize = maxScore/(len(hist) / squashFactor)

    bins = []
    curTotal = 0
    binIdx = 0
    for i, val in enumerate(hist):
        if i != 0 and (i % squashFactor) == 0:
            AddBin(bins, binSize, binIdx, curTotal)
            curTotal = 0
            binIdx += 1

        curTotal += val
    AddBin(bins, binSize, binIdx, curTotal)

    graph = Pyasciigraph()

    for line in graph.graph(GetGraphTitle(tversky, shapeOnly), bins):
        print(line)


def GetFormatExtension(fname):
    base, ext = os.path.splitext(fname.lower())
    if ext == ".gz":
        base, ext = os.path.splitext(base)
        ext += ".gz"
    return ext


def main(argv=[__name__]):

    parser = argparse.ArgumentParser()

    # positional arguments retaining backward compatibility
    parser.add_argument('server:port', help='Server name and port number of database to search i.e. localhost:8080.')
    parser.add_argument('query', help='File containing the query molecule to search (format not restricted to *.oeb).')
    parser.add_argument('results', help='Output file to store results (format not restricted to *.oeb).')
    parser.add_argument('nHits', nargs='?', type=int, default=100,
                        help='Number of hits to return (default=100).')
    parser.add_argument('--tversky', action='store_true', default=argparse.SUPPRESS,
                        help='Switch to Tversky similarity scoring (default=Tanimoto).')
    parser.add_argument('--shapeOnly', action='store_true', default=argparse.SUPPRESS,
                        help='Switch to shape-only scores (default=Combo).')
    parser.add_argument('--alternativeStarts', default=argparse.SUPPRESS, nargs=1, dest='altStarts',
                        choices=('random', 'subrocs', 'inertialAtHeavyAtoms', 'inertialAtColorAtoms'),
                        help='Optimize using alternative starts. '
                             'To perform N random starts do "--alternativeStarts random N" (default N=10)')

    known, remaining = (parser.parse_known_args())
    dargs = vars(known)

    qfname = dargs.pop('query')
    numHits = dargs.pop('nHits')

    startType = dargs.get('altStarts', None)

    if startType:
        dargs['altStarts'] = str(startType[0])
        if len(remaining) == 1 and dargs['altStarts'] == 'random':
            try:
                numRands = int(remaining[0])
                dargs['randStarts'] = numRands
            except ValueError:
                print("Invalid argument given. See --help menu for argument list")
                sys.exit()
        if len(remaining) > 1:
            print("Too many arguments given. See --help menu for argument list")
            sys.exit()
    else:
        if remaining:
            print("Too many arguments given. See --help menu for argument list")
            sys.exit()

    try:
        fh = open(qfname, 'rb')
    except IOError:
        sys.stderr.write("Unable to open '%s' for reading" % qfname)
        return 1

    iformat = GetFormatExtension(qfname)

    ofname = dargs.pop('results')
    oformat = GetFormatExtension(ofname)

    s = ServerProxy("http://" + dargs.pop('server:port'))
    data = Binary(fh.read())

    try:
        idx = s.SubmitQuery(data, numHits, iformat, oformat, dargs)
    except Fault as e:
        sys.stderr.write(str(e))
        return 1

    while True:
        blocking = True
        try:
            current, total = s.QueryStatus(idx, blocking)
            hist = s.QueryHistogram(idx)
        except Fault as e:
            print(str(e), file=sys.stderr)
            return 1

        if total == 0:
            continue

        PrintHistogram(hist, dargs.get('tversky', None), dargs.get('shapeOnly', None))

        if total <= current:
            break

    results = s.QueryResults(idx)

    # assuming the results come back as a string in the requested format
    with open(ofname, 'wb') as output:
        output.write(results.data)

    return 0


if __name__ == '__main__':
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from __future__ import print_function

from openeye import oechem
from openeye import oegrid
from openeye import oeshape


def main(argv=[__name__]):
    if len(argv) != 3:
        oechem.OEThrow.Usage("%s <molfile> <outfile>" % argv[0])

    molfs = oechem.oemolistream(sys.argv[1])
    mol = oechem.OEGraphMol()
    oechem.OEReadMolecule(molfs, mol)

    # Use OEOverlapPrep to remove hydrogens and add
    # color atoms to the molecule
    prep = oeshape.OEOverlapPrep()
    prep.Prep(mol)

    # Get the color atoms, create gaussians and add them
    # to the shape query
    query = oeshape.OEShapeQuery()
    for atom in oeshape.OEGetColorAtoms(mol):
        coords = oechem.OEFloatArray(3)
        mol.GetCoords(atom, coords)
        gauss = oegrid.OEGaussian(1.0, 1.0, coords, oeshape.OEGetColorType(atom))
        query.AddColorGaussian(gauss)

    # Remove color atoms from the molecule and add to the query
    oeshape.OERemoveColorAtoms(mol)
    query.SetMolecule(mol)

    oeshape.OEWriteShapeQuery(sys.argv[2], query)
    print("shape query created")


if __name__ == "__main__":
    import sys
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Set phi, psi and chis torsion angles in a protein
#############################################################################
from __future__ import print_function
import sys
import math
from openeye import oechem


def MakeAlpha(ifs, ofs):
    phival = math.pi / -3.0
    psival = math.pi / -3.0
    chival = math.pi
    nrphis = 0
    nrpsis = 0
    nrchis = 0
    mol = oechem.OEGraphMol()
    while oechem.OEReadMolecule(ifs, mol):
        if not oechem.OEHasResidues(mol):
            oechem.OEPerceiveResidues(mol, oechem.OEPreserveResInfo_All)
        # remove cross-links
        for bond in mol.GetBonds():
            if bond.GetBgn().GetAtomicNum() == oechem.OEElemNo_S and \
               bond.GetEnd().GetAtomicNum() == oechem.OEElemNo_S:
                mol.DeleteBond(bond)

        oechem.OEFindRingAtomsAndBonds(mol)
        hv = oechem.OEHierView(mol)
        for res in hv.GetResidues():
            if not oechem.OEIsStandardProteinResidue(res):
                continue

            # set psi and phi angles
            if not oechem.OESetTorsion(res, oechem.OEProtTorType_Phi, phival):
                oeres = res.GetOEResidue()
                print("Unable to set phi for %s %d" % (oeres.GetName(),
                                                       oeres.GetResidueNumber()))
            else:
                nrphis += 1

            if not oechem.OESetTorsion(res, oechem.OEProtTorType_Psi, psival):
                oeres = res.GetOEResidue()
                print("Unable to set psi for %s %d" % (oeres.GetName(),
                                                       oeres.GetResidueNumber()))
            else:
                nrpsis += 1

            # set chis
            if oechem.OEGetResidueIndex(res.GetOEResidue().GetName()) == oechem.OEResidueIndex_PRO:
                continue  # It does not make sense to set Proline chi angles to 180

            for chi in oechem.OEGetChis(res):
                if not oechem.OESetTorsion(res, chi, chival):
                    oeres = res.GetOEResidue()
                    print("Unable to set chi %s for %s %d" % (
                                                              oechem.OEGetProteinTorsionName(chi),
                                                              oeres.GetName(),
                                                              oeres.GetResidueNumber()))
                else:
                    nrchis += 1
        oechem.OEWriteMolecule(ofs, mol)

    print(nrphis, " phi  torsion angle set to ", phival * oechem.cvar.Rad2Deg)
    print(nrpsis, " psi  torsion angle set to ", psival * oechem.cvar.Rad2Deg)
    print(nrchis, " chis torsion angle set to ", chival * oechem.cvar.Rad2Deg)


def main(argv=[__name__]):
    if len(sys.argv) != 3:
        oechem.OEThrow.Usage("makealpha.py <infile> <outfile>")
    ifs = oechem.oemolistream()
    if not ifs.open(argv[1]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % argv[1])
    ofs = oechem.oemolostream()
    if not ofs.open(argv[2]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % argv[2])
    MakeAlpha(ifs, ofs)


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Searching fast fingerprint database
#############################################################################
import sys
from openeye import oechem
from openeye import oegraphsim


def main(argv=[__name__]):

    itf = oechem.OEInterface()
    oechem.OEConfigure(itf, InterfaceData)

    defopts = oegraphsim.OEFPDatabaseOptions(10, oegraphsim.OESimMeasure_Tanimoto)
    oegraphsim.OEConfigureFPDatabaseOptions(itf, defopts)
    oegraphsim.OEConfigureFPDatabaseMemoryType(itf)

    if not oechem.OEParseCommandLine(itf, argv):
        return 0

    qfname = itf.GetString("-query")
    mfname = itf.GetString("-molfname")
    ffname = itf.GetString("-fpdbfname")
    ofname = itf.GetString("-out")

    # initialize databases

    timer = oechem.OEWallTimer()
    timer.Start()

    ifs = oechem.oemolistream()
    if not ifs.open(qfname):
        oechem.OEThrow.Fatal("Cannot open input file!")

    query = oechem.OEGraphMol()
    if not oechem.OEReadMolecule(ifs, query):
        oechem.OEThrow.Fatal("Cannot read query molecule!")

    moldb = oechem.OEMolDatabase()
    if not moldb.Open(mfname):
        oechem.OEThrow.Fatal("Cannot open molecule database!")

    memtype = oegraphsim.OEGetFPDatabaseMemoryType(itf)

    fpdb = oegraphsim.OEFastFPDatabase(ffname, memtype)
    if not fpdb.IsValid():
        oechem.OEThrow.Fatal("Cannot open fingerprint database!")
    nrfps = fpdb.NumFingerPrints()
    memtypestr = fpdb.GetMemoryTypeString()

    ofs = oechem.oemolostream()
    if not ofs.open(ofname):
        oechem.OEThrow.Fatal("Cannot open output file!")

    if not oegraphsim.OEAreCompatibleDatabases(moldb, fpdb):
        oechem.OEThrow.Fatal("Databases are not compatible!")

    oechem.OEThrow.Info("%5.2f sec to initialize databases" % timer.Elapsed())

    fptype = fpdb.GetFPTypeBase()
    oechem.OEThrow.Info("Using fingerprint type %s" % fptype.GetFPTypeString())

    opts = oegraphsim.OEFPDatabaseOptions()
    oegraphsim.OESetupFPDatabaseOptions(opts, itf)

    # search fingerprint database

    timer.Start()
    scores = fpdb.GetSortedScores(query, opts)
    oechem.OEThrow.Info("%5.2f sec to search %d fingerprints %s" % (timer.Elapsed(), nrfps, memtypestr))

    timer.Start()
    nrhits = 0
    hit = oechem.OEGraphMol()
    for si in scores:
        if moldb.GetMolecule(hit, si.GetIdx()):
            nrhits += 1
            oechem.OESetSDData(hit, "Similarity score", "%.2f" % si.GetScore())
            oechem.OEWriteMolecule(ofs, hit)
    oechem.OEThrow.Info("%5.2f sec to write %d hits" % (timer.Elapsed(), nrhits))

    return 0


InterfaceData = """
!BRIEF [-query] <molfile> [-molfname] <molfile> [-fpdbfname] <fpfile>  [-out] <molfile>

!CATEGORY "input/output options"

  !PARAMETER -query
    !ALIAS -q
    !TYPE string
    !REQUIRED true
    !KEYLESS 1
    !VISIBILITY simple
    !BRIEF Input query filename
  !END

  !PARAMETER -molfname
    !ALIAS -mol
    !TYPE string
    !REQUIRED true
    !KEYLESS 2
    !VISIBILITY simple
    !BRIEF Input molecule filename
  !END

  !PARAMETER -fpdbfname
    !ALIAS -fpdb
    !TYPE string
    !REQUIRED true
    !KEYLESS 3
    !VISIBILITY simple
    !BRIEF Input fast fingerprint database filename
  !END

  !PARAMETER -out
    !ALIAS -o
    !TYPE string
    !REQUIRED true
    !KEYLESS 4
    !VISIBILITY simple
    !BRIEF Output molecule filename
  !END

!END
"""

if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oegraphsim

# @ <SNIPPET-SDF2FP>
if len(sys.argv) != 2:
    oechem.OEThrow.Usage("%s <infile>" % sys.argv[0])

ifs = oechem.oemolistream()
if not ifs.open(sys.argv[1]):
    oechem.OEThrow.Fatal("Unable to open %s for reading" % sys.argv[1])
if ifs.GetFormat() != oechem.OEFormat_SDF:
    oechem.OEThrow.Fatal("%s input file has to be an SDF file" % sys.argv[1])

molcounter = 0
fpcounter = 0
for mol in ifs.GetOEGraphMols():
    molcounter += 1
    for dp in oechem.OEGetSDDataPairs(mol):
        if oegraphsim.OEIsValidFPTypeString(dp.GetTag()):
            fpcounter += 1
            fptypestr = dp.GetTag()
            fphexdata = dp.GetValue()

            fp = oegraphsim.OEFingerPrint()
            fptype = oegraphsim.OEGetFPType(fptypestr)
            fp.SetFPTypeBase(fptype)
            fp.FromHexString(fphexdata)

print("Number of molecules = %d" % molcounter)
print("Number of fingerprints = %d" % fpcounter)
# @ </SNIPPET-SDF2FP>



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from __future__ import print_function
import sys
from openeye import oechem


def PrintResidues(mol):
    """list alternate location code and occupancy by group and residue"""
    if not oechem.OEHasResidues(mol):
        oechem.OEPerceiveResidues(mol, oechem.OEPreserveResInfo_All)

    alf = oechem.OEAltLocationFactory(mol)

    print("%s - %d alternate location groups:" %
          (mol.GetTitle(), alf.GetGroupCount()))

    for grp in alf.GetGroups():
        print("%d) %d alternate locations" %
              (grp.GetGroupID() + 1, grp.GetLocationCount()), end=" ")

        prev = oechem.OEResidue()
        prevCodes = ""
        sumOcc = []
        atNum = []

        for atom in alf.GetAltAtoms(grp):
            res = oechem.OEAtomGetResidue(atom)
            if not oechem.OESameResidue(res, prev):
                for i, code in enumerate(prevCodes):
                    print("%c(%.0f%c) " %
                          (code, (sumOcc[i] * 100.0)/atNum[i], "%"), end=" ")
                print()
                prevCodes = ""
                sumOcc = []
                atNum = []

                print("\t%s%d%c chain '%c': " %
                      (res.GetName(), res.GetResidueNumber(),
                       res.GetInsertCode(), res.GetChainID()), end=" ")
                prev = res

            code = res.GetAlternateLocation()
            whichCode = prevCodes.find(code)
            if whichCode < 0:
                prevCodes += code
                sumOcc.append(res.GetOccupancy())
                atNum.append(1)
            else:
                sumOcc[whichCode] += res.GetOccupancy()
                atNum[whichCode] += 1

        for i, code in enumerate(prevCodes):
            print("%c(%.0f%c) " %
                  (code, (sumOcc[i] * 100.0)/atNum[i], "%"), end=" ")
        print()


def main(argv=[__name__]):
    if len(argv) != 2:
        oechem.OEThrow.Usage("%s <mol-infile>" % argv[0])

    ifs = oechem.oemolistream()
    if not ifs.open(argv[1]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % argv[1])

    # need this flavor to read alt loc atoms
    ifs.SetFlavor(oechem.OEFormat_PDB, oechem.OEIFlavor_PDB_ALTLOC)

    for mol in ifs.GetOEGraphMols():
        PrintResidues(mol)


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from __future__ import print_function
import sys

from openeye import oechem
from openeye import oedocking


def SetCustomConstraints(receptor, proteinHeavyAtom):
    # @ <SNIPPET-RECEPTOR-CUSTOM-CONSTRAINT-EDITING-3>
    customConstraints = oedocking.OEReceptorGetCustomConstraints(receptor)

    feature = customConstraints.AddFeature()
    feature.SetFeatureName("Example protein contact constraint")

    sphereRadius = 4.0
    sphereCenter = oechem.OEFloatArray(3)
    receptor.GetCoords(proteinHeavyAtom, sphereCenter)
    sphere = feature.AddSphere()
    sphere.SetRad(sphereRadius)
    sphere.SetCenter(sphereCenter[0], sphereCenter[1], sphereCenter[2])

    oedocking.OEReceptorSetCustomConstraints(receptor, customConstraints)
    # @ </SNIPPET-RECEPTOR-CUSTOM-CONSTRAINT-EDITING-3>


def main(argv=[__name__]):
    if len(argv) != 2:
        oechem.OEThrow.Usage("%s <receptor>" % argv[0])

    receptor = oechem.OEGraphMol()
    oedocking.OEReadReceptorFile(receptor, argv[1])

    # @ <SNIPPET-RECEPTOR-CUSTOM-CONSTRAINT-EDITING-1>
    if oedocking.OEReceptorHasCustomConstraints(receptor):
        print("Receptor has custom constraints")
    else:
        print("Receptor does not have custom constraints")
    # @ </SNIPPET-RECEPTOR-CUSTOM-CONSTRAINT-EDITING-1>

    # @ <SNIPPET-RECEPTOR-CUSTOM-CONSTRAINT-EDITING-2>
    customConstraints = oedocking.OEReceptorGetCustomConstraints(receptor)
    for feature in customConstraints.GetFeatures():
        print("Feature", feature.GetFeatureName())
        print("  Spheres : ")
        for sphere in feature.GetSpheres():
            print("    center (", sphere.GetX(), ", ", sphere.GetY(),
                  ", ", sphere.GetZ(), ")  radius ", sphere.GetRad())
        smartsIter = feature.GetSmarts()
        if not smartsIter.IsValid():
            print("  Constraint is matched by any heavy atom")
        else:
            print("  SMARTS:")
            for smarts in smartsIter:
                print("    " + smarts)
    # @ </SNIPPET-RECEPTOR-CUSTOM-CONSTRAINT-EDITING-2>

    for heavyAtom in receptor.GetAtoms():
        if not heavyAtom.IsHydrogen():
            SetCustomConstraints(receptor, heavyAtom)
            break

    # @ <SNIPPET-RECEPTOR-CUSTOM-CONSTRAINT-EDITING-4>
    oedocking.OEReceptorClearCustomConstraints(receptor)
    # @ </SNIPPET-RECEPTOR-CUSTOM-CONSTRAINT-EDITING-4>


if __name__ == "__main__":
    sys.exit(main(sys.argv))
